@@ -4,16 +4,19 @@
 from enum import Enum
 from typing import Optional, List, Set, Dict, Tuple, Union, TYPE_CHECKING
 
+from slither.all_exceptions import SlitherException
 from slither.core.children.child_function import ChildFunction
+from slither.core.declarations import Contract, Function
 from slither.core.declarations.solidity_variables import (
     SolidityVariable,
     SolidityFunction,
 )
+from slither.core.expressions.expression import Expression
+from slither.core.solidity_types import ElementaryType
 from slither.core.source_mapping.source_mapping import SourceMapping
 from slither.core.variables.local_variable import LocalVariable
 from slither.core.variables.state_variable import StateVariable
 from slither.core.variables.variable import Variable
-from slither.core.solidity_types import ElementaryType
 from slither.slithir.convert import convert_expression
 from slither.slithir.operations import (
     HighLevelCall,
@@ -38,13 +41,8 @@ from slither.slithir.variables import (
     TemporaryVariable,
     TupleVariable,
 )
-from slither.all_exceptions import SlitherException
-from slither.core.declarations import Contract
-
-from slither.core.expressions.expression import Expression
 
 if TYPE_CHECKING:
-    from slither.core.declarations import Function
     from slither.slithir.variables.variable import SlithIRVariable
     from slither.core.compilation_unit import SlitherCompilationUnit
     from slither.utils.type_helpers import (
@@ -67,80 +65,41 @@ if TYPE_CHECKING:
 
 
 class NodeType(Enum):
-    ENTRYPOINT = 0x0  # no expression
+    ENTRYPOINT = "ENTRY_POINT"  # no expression
 
-    # Node with expression
+    # Nodes that may have an expression
 
-    EXPRESSION = 0x10  # normal case
-    RETURN = 0x11  # RETURN may contain an expression
-    IF = 0x12
-    VARIABLE = 0x13  # Declaration of variable
-    ASSEMBLY = 0x14
-    IFLOOP = 0x15
+    EXPRESSION = "EXPRESSION"  # normal case
+    RETURN = "RETURN"  # RETURN may contain an expression
+    IF = "IF"
+    VARIABLE = "NEW VARIABLE"  # Variable declaration
+    ASSEMBLY = "INLINE ASM"
+    IFLOOP = "IF_LOOP"
 
-    # Merging nodes
+    # Nodes where control flow merges
     # Can have phi IR operation
-    ENDIF = 0x50  # ENDIF node source mapping points to the if/else body
-    STARTLOOP = 0x51  # STARTLOOP node source mapping points to the entire loop body
-    ENDLOOP = 0x52  # ENDLOOP node source mapping points to the entire loop body
+    ENDIF = "END_IF"  # ENDIF node source mapping points to the if/else "body"
+    STARTLOOP = "BEGIN_LOOP"  # STARTLOOP node source mapping points to the entire loop "body"
+    ENDLOOP = "END_LOOP"  # ENDLOOP node source mapping points to the entire loop "body"
 
-    # Below the nodes have no expression
-    # But are used to expression CFG structure
+    # Below the nodes do not have an expression but are used to expression CFG structure.
 
     # Absorbing node
-    THROW = 0x20
+    THROW = "THROW"
 
     # Loop related nodes
-    BREAK = 0x31
-    CONTINUE = 0x32
+    BREAK = "BREAK"
+    CONTINUE = "CONTINUE"
 
     # Only modifier node
-    PLACEHOLDER = 0x40
+    PLACEHOLDER = "_"
 
-    TRY = 0x41
-    CATCH = 0x42
+    TRY = "TRY"
+    CATCH = "CATCH"
 
     # Node not related to the CFG
     # Use for state variable declaration
-    OTHER_ENTRYPOINT = 0x60
-
-    #    @staticmethod
-    def __str__(self):
-        if self == NodeType.ENTRYPOINT:
-            return "ENTRY_POINT"
-        if self == NodeType.EXPRESSION:
-            return "EXPRESSION"
-        if self == NodeType.RETURN:
-            return "RETURN"
-        if self == NodeType.IF:
-            return "IF"
-        if self == NodeType.VARIABLE:
-            return "NEW VARIABLE"
-        if self == NodeType.ASSEMBLY:
-            return "INLINE ASM"
-        if self == NodeType.IFLOOP:
-            return "IF_LOOP"
-        if self == NodeType.THROW:
-            return "THROW"
-        if self == NodeType.BREAK:
-            return "BREAK"
-        if self == NodeType.CONTINUE:
-            return "CONTINUE"
-        if self == NodeType.PLACEHOLDER:
-            return "_"
-        if self == NodeType.TRY:
-            return "TRY"
-        if self == NodeType.CATCH:
-            return "CATCH"
-        if self == NodeType.ENDIF:
-            return "END_IF"
-        if self == NodeType.STARTLOOP:
-            return "BEGIN_LOOP"
-        if self == NodeType.ENDLOOP:
-            return "END_LOOP"
-        if self == NodeType.OTHER_ENTRYPOINT:
-            return "OTHER_ENTRYPOINT"
-        return "Unknown type {}".format(hex(self.value))
+    OTHER_ENTRYPOINT = "OTHER_ENTRYPOINT"
 
 
 # endregion
@@ -159,7 +118,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         node_id: int,
         scope: Union["Scope", "Function"],
         file_scope: "FileScope",
-    ):
+    ) -> None:
         super().__init__()
         self._node_type = node_type
 
@@ -514,11 +473,11 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         """
         return self._expression
 
-    def add_expression(self, expression: Expression, bypass_verif_empty: bool = False):
+    def add_expression(self, expression: Expression, bypass_verif_empty: bool = False) -> None:
         assert self._expression is None or bypass_verif_empty
         self._expression = expression
 
-    def add_variable_declaration(self, var: LocalVariable):
+    def add_variable_declaration(self, var: LocalVariable) -> None:
         assert self._variable_declaration is None
         self._variable_declaration = var
         if var.expression:
@@ -551,7 +510,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
             for c in self.internal_calls
         )
 
-    def contains_if(self, include_loop=True) -> bool:
+    def contains_if(self, include_loop: bool = True) -> bool:
         """
             Check if the node is a IF node
         Returns:
@@ -561,7 +520,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
             return self.type in [NodeType.IF, NodeType.IFLOOP]
         return self.type == NodeType.IF
 
-    def is_conditional(self, include_loop=True) -> bool:
+    def is_conditional(self, include_loop: bool = True) -> bool:
         """
             Check if the node is a conditional node
             A conditional node is either a IF or a require/assert or a RETURN bool
@@ -590,7 +549,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     def inline_asm(self) -> Optional[Union[str, Dict]]:
         return self._asm_source_code
 
-    def add_inline_asm(self, asm: Union[str, Dict]):
+    def add_inline_asm(self, asm: Union[str, Dict]) -> None:
         self._asm_source_code = asm
 
     # endregion
@@ -600,7 +559,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     ###################################################################################
     ###################################################################################
 
-    def add_father(self, father: "Node"):
+    def add_father(self, father: "Node") -> None:
         """Add a father node
 
         Args:
@@ -625,7 +584,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         """
         return list(self._fathers)
 
-    def remove_father(self, father: "Node"):
+    def remove_father(self, father: "Node") -> None:
         """Remove the father node. Do nothing if the node is not a father
 
         Args:
@@ -633,7 +592,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         """
         self._fathers = [x for x in self._fathers if x.node_id != father.node_id]
 
-    def remove_son(self, son: "Node"):
+    def remove_son(self, son: "Node") -> None:
         """Remove the son node. Do nothing if the node is not a son
 
         Args:
@@ -641,7 +600,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         """
         self._sons = [x for x in self._sons if x.node_id != son.node_id]
 
-    def add_son(self, son: "Node"):
+    def add_son(self, son: "Node") -> None:
         """Add a son node
 
         Args:
@@ -649,7 +608,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         """
         self._sons.append(son)
 
-    def set_sons(self, sons: List["Node"]):
+    def set_sons(self, sons: List["Node"]) -> None:
         """Set the son nodes
 
         Args:
@@ -707,14 +666,14 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     def irs_ssa(self, irs):
         self._irs_ssa = irs
 
-    def add_ssa_ir(self, ir: Operation):
+    def add_ssa_ir(self, ir: Operation) -> None:
         """
         Use to place phi operation
         """
         ir.set_node(self)
         self._irs_ssa.append(ir)
 
-    def slithir_generation(self):
+    def slithir_generation(self) -> None:
         if self.expression:
             expression = self.expression
             self._irs = convert_expression(expression, self)
@@ -731,11 +690,11 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         return self._all_slithir_operations
 
     @staticmethod
-    def _is_non_slithir_var(var: Variable):
+    def _is_non_slithir_var(var: Variable) -> bool:
         return not isinstance(var, (Constant, ReferenceVariable, TemporaryVariable, TupleVariable))
 
     @staticmethod
-    def _is_valid_slithir_var(var: Variable):
+    def _is_valid_slithir_var(var: Variable) -> bool:
         return isinstance(var, (ReferenceVariable, TemporaryVariable, TupleVariable))
 
     # endregion
@@ -786,7 +745,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         self._dominance_frontier = doms
 
     @property
-    def dominator_successors(self):
+    def dominator_successors(self) -> Set["Node"]:
         return self._dom_successors
 
     @property
@@ -828,14 +787,14 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     # def phi_origin_member_variables(self) -> Dict[str, Tuple[MemberVariable, Set["Node"]]]:
     #     return self._phi_origins_member_variables
 
-    def add_phi_origin_local_variable(self, variable: LocalVariable, node: "Node"):
+    def add_phi_origin_local_variable(self, variable: LocalVariable, node: "Node") -> None:
         if variable.name not in self._phi_origins_local_variables:
             self._phi_origins_local_variables[variable.name] = (variable, set())
         (v, nodes) = self._phi_origins_local_variables[variable.name]
         assert v == variable
         nodes.add(node)
 
-    def add_phi_origin_state_variable(self, variable: StateVariable, node: "Node"):
+    def add_phi_origin_state_variable(self, variable: StateVariable, node: "Node") -> None:
         if variable.canonical_name not in self._phi_origins_state_variables:
             self._phi_origins_state_variables[variable.canonical_name] = (
                 variable,
@@ -859,7 +818,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     ###################################################################################
     ###################################################################################
 
-    def _find_read_write_call(self):  # pylint: disable=too-many-statements
+    def _find_read_write_call(self) -> None:  # pylint: disable=too-many-statements
 
         for ir in self.irs:
 
@@ -913,10 +872,11 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
                     except AttributeError as error:
                         #  pylint: disable=raise-missing-from
                         raise SlitherException(
-                            f"Function not found on IR: {ir}.\nNode: {self} ({self.source_mapping_str})\nFunction: {self.function}\nPlease try compiling with a recent Solidity version. {error}"
+                            f"Function not found on IR: {ir}.\nNode: {self} ({self.source_mapping})\nFunction: {self.function}\nPlease try compiling with a recent Solidity version. {error}"
                         )
             elif isinstance(ir, LibraryCall):
                 assert isinstance(ir.destination, Contract)
+                assert isinstance(ir.function, Function)
                 self._high_level_calls.append((ir.destination, ir.function))
                 self._library_calls.append((ir.destination, ir.function))
 
@@ -934,7 +894,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         self._low_level_calls = list(set(self._low_level_calls))
 
     @staticmethod
-    def _convert_ssa(v: Variable):
+    def _convert_ssa(v: Variable) -> Optional[Union[StateVariable, LocalVariable]]:
         if isinstance(v, StateIRVariable):
             contract = v.contract
             non_ssa_var = contract.get_state_variable_from_name(v.name)
@@ -944,7 +904,7 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
         non_ssa_var = function.get_local_variable_from_name(v.name)
         return non_ssa_var
 
-    def update_read_write_using_ssa(self):
+    def update_read_write_using_ssa(self) -> None:
         if not self.expression:
             return
         for ir in self.irs_ssa:
@@ -1008,13 +968,13 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
     ###################################################################################
     ###################################################################################
 
-    def __str__(self):
+    def __str__(self) -> str:
         additional_info = ""
         if self.expression:
             additional_info += " " + str(self.expression)
         elif self.variable_declaration:
             additional_info += " " + str(self.variable_declaration)
-        txt = str(self._node_type) + additional_info
+        txt = self._node_type.value + additional_info
         return txt
 
 
@@ -1026,12 +986,12 @@ class Node(SourceMapping, ChildFunction):  # pylint: disable=too-many-public-met
 ###################################################################################
 
 
-def link_nodes(node1: Node, node2: Node):
+def link_nodes(node1: Node, node2: Node) -> None:
     node1.add_son(node2)
     node2.add_father(node1)
 
 
-def insert_node(origin: Node, node_inserted: Node):
+def insert_node(origin: Node, node_inserted: Node) -> None:
     sons = origin.sons
     link_nodes(origin, node_inserted)
     for son in sons:
