@@ -1,13 +1,26 @@
 """
     Function module
 """
-from typing import List, Tuple
+from typing import Dict, List, Tuple, TYPE_CHECKING
 
 from slither.core.declarations import Function
 from slither.core.declarations.top_level import TopLevel
 
+if TYPE_CHECKING:
+    from slither.core.compilation_unit import SlitherCompilationUnit
+    from slither.core.scope.scope import FileScope
+    from slither.slithir.variables.state_variable import StateIRVariable
+
 
 class FunctionTopLevel(Function, TopLevel):
+    def __init__(self, compilation_unit: "SlitherCompilationUnit", scope: "FileScope") -> None:
+        super().__init__(compilation_unit)
+        self._scope: "FileScope" = scope
+
+    @property
+    def file_scope(self) -> "FileScope":
+        return self._scope
+
     @property
     def canonical_name(self) -> str:
         """
@@ -16,7 +29,9 @@ class FunctionTopLevel(Function, TopLevel):
         """
         if self._canonical_name is None:
             name, parameters, _ = self.signature
-            self._canonical_name = ".".join(self._scope + [name]) + "(" + ",".join(parameters) + ")"
+            self._canonical_name = (
+                ".".join(self._internal_scope + [name]) + "(" + ",".join(parameters) + ")"
+            )
         return self._canonical_name
 
     # endregion
@@ -64,7 +79,9 @@ class FunctionTopLevel(Function, TopLevel):
     ###################################################################################
     ###################################################################################
 
-    def generate_slithir_ssa(self, all_ssa_state_variables_instances):
+    def generate_slithir_ssa(
+        self, all_ssa_state_variables_instances: Dict[str, "StateIRVariable"]
+    ) -> None:
         # pylint: disable=import-outside-toplevel
         from slither.slithir.utils.ssa import add_ssa_ir, transform_slithir_vars_to_ssa
         from slither.core.dominators.utils import (
