@@ -1,12 +1,16 @@
-from typing import List
+from typing import List, TYPE_CHECKING
 
 from slither.core.source_mapping.source_mapping import SourceMapping
 
+if TYPE_CHECKING:
+    from slither.core.scope.scope import FileScope
+
 
 class Pragma(SourceMapping):
-    def __init__(self, directive: List[str]):
+    def __init__(self, directive: List[str], scope: "FileScope") -> None:
         super().__init__()
         self._directive = directive
+        self.scope: "FileScope" = scope
 
     @property
     def directive(self) -> List[str]:
@@ -35,5 +39,5 @@ class Pragma(SourceMapping):
             return self._directive[0] == "experimental" and self._directive[1] == "ABIEncoderV2"
         return False
 
-    def __str__(self):
+    def __str__(self) -> str:
         return "pragma " + "".join(self.directive)
