@@ -1,13 +1,11 @@
 # https://solidity.readthedocs.io/en/v0.4.24/units-and-global-variables.html
-from typing import List, Dict, Union, TYPE_CHECKING
+from typing import List, Dict, Union, Any
 
 from slither.core.declarations.custom_error import CustomError
 from slither.core.solidity_types import ElementaryType, TypeInformation
 from slither.core.source_mapping.source_mapping import SourceMapping
 from slither.exceptions import SlitherException
 
-if TYPE_CHECKING:
-    pass
 
 SOLIDITY_VARIABLES = {
     "now": "uint256",
@@ -98,13 +96,13 @@ def solidity_function_signature(name):
 
 
 class SolidityVariable(SourceMapping):
-    def __init__(self, name: str):
+    def __init__(self, name: str) -> None:
         super().__init__()
         self._check_name(name)
         self._name = name
 
     # dev function, will be removed once the code is stable
-    def _check_name(self, name: str):  # pylint: disable=no-self-use
+    def _check_name(self, name: str) -> None:  # pylint: disable=no-self-use
         assert name in SOLIDITY_VARIABLES or name.endswith(("_slot", "_offset"))
 
     @property
@@ -124,18 +122,18 @@ class SolidityVariable(SourceMapping):
     def type(self) -> ElementaryType:
         return ElementaryType(SOLIDITY_VARIABLES[self.name])
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self._name
 
-    def __eq__(self, other):
+    def __eq__(self, other: SourceMapping) -> bool:
         return self.__class__ == other.__class__ and self.name == other.name
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(self.name)
 
 
 class SolidityVariableComposed(SolidityVariable):
-    def _check_name(self, name: str):
+    def _check_name(self, name: str) -> None:
         assert name in SOLIDITY_VARIABLES_COMPOSED
 
     @property
@@ -146,13 +144,13 @@ class SolidityVariableComposed(SolidityVariable):
     def type(self) -> ElementaryType:
         return ElementaryType(SOLIDITY_VARIABLES_COMPOSED[self.name])
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self._name
 
-    def __eq__(self, other):
+    def __eq__(self, other: Any) -> bool:
         return self.__class__ == other.__class__ and self.name == other.name
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(self.name)
 
 
@@ -162,7 +160,7 @@ class SolidityFunction(SourceMapping):
     # https://solidity.readthedocs.io/en/latest/units-and-global-variables.html#type-information
     # As a result, we set return_type during the Ir conversion
 
-    def __init__(self, name: str):
+    def __init__(self, name: str) -> None:
         super().__init__()
         assert name in SOLIDITY_FUNCTIONS
         self._name = name
@@ -187,28 +185,28 @@ class SolidityFunction(SourceMapping):
     def return_type(self, r: List[Union[TypeInformation, ElementaryType]]):
         self._return_type = r
 
-    def __str__(self):
+    def __str__(self) -> str:
         return self._name
 
-    def __eq__(self, other):
+    def __eq__(self, other: "SolidityFunction") -> bool:
         return self.__class__ == other.__class__ and self.name == other.name
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(self.name)
 
 
 class SolidityCustomRevert(SolidityFunction):
-    def __init__(self, custom_error: CustomError):  # pylint: disable=super-init-not-called
+    def __init__(self, custom_error: CustomError) -> None:  # pylint: disable=super-init-not-called
         self._name = "revert " + custom_error.solidity_signature
         self._custom_error = custom_error
         self._return_type: List[Union[TypeInformation, ElementaryType]] = []
 
-    def __eq__(self, other):
+    def __eq__(self, other: Union["SolidityCustomRevert", SolidityFunction]) -> bool:
         return (
             self.__class__ == other.__class__
             and self.name == other.name
             and self._custom_error == other._custom_error
         )
 
-    def __hash__(self):
+    def __hash__(self) -> int:
         return hash(hash(self.name) + hash(self._custom_error))
