@@ -1,4 +1,4 @@
-from typing import List, TYPE_CHECKING
+from typing import Set, List, TYPE_CHECKING
 
 from slither.core.cfg.node import NodeType
 
@@ -6,7 +6,7 @@ if TYPE_CHECKING:
     from slither.core.cfg.node import Node
 
 
-def intersection_predecessor(node: "Node"):
+def intersection_predecessor(node: "Node") -> Set["Node"]:
     if not node.fathers:
         return set()
     ret = node.fathers[0].dominators
@@ -15,18 +15,9 @@ def intersection_predecessor(node: "Node"):
     return ret
 
 
-def compute_dominators(nodes: List["Node"]):
-    """
-    Naive implementation of Cooper, Harvey, Kennedy algo
-    See 'A Simple,Fast Dominance Algorithm'
-
-    Compute strict domniators
-    """
+def _compute_dominators(nodes: List["Node"]) -> None:
     changed = True
 
-    for n in nodes:
-        n.dominators = set(nodes)
-
     while changed:
         changed = False
 
@@ -36,20 +27,30 @@ def compute_dominators(nodes: List["Node"]):
                 node.dominators = new_set
                 changed = True
 
-    # compute immediate dominator
+
+def _compute_immediate_dominators(nodes: List["Node"]) -> None:
     for node in nodes:
         idom_candidates = set(node.dominators)
         idom_candidates.remove(node)
 
-        for dominator in node.dominators:
-            if dominator != node:
-                # pylint: disable=expression-not-assigned
-                [
-                    idom_candidates.remove(d)
-                    for d in dominator.dominators
-                    if d in idom_candidates and d != dominator
-                ]
+        if len(idom_candidates) == 1:
+            idom = idom_candidates.pop()
+            node.immediate_dominator = idom
+            idom.dominator_successors.add(node)
+            continue
 
+        # all_dominators contain all the dominators of all the node's dominators
+        # But self inclusion is removed
+        # The idom is then the only node that in idom_candidate that is not in all_dominators
+        all_dominators = set()
+        for d in idom_candidates:
+            # optimization: if a node is already in all_dominators, then
+            # its dominators are already in too
+            if d in all_dominators:
+                continue
+            all_dominators |= d.dominators - {d}
+
+        idom_candidates = all_dominators.symmetric_difference(idom_candidates)
         assert len(idom_candidates) <= 1
         if idom_candidates:
             idom = idom_candidates.pop()
@@ -57,7 +58,23 @@ def compute_dominators(nodes: List["Node"]):
             idom.dominator_successors.add(node)
 
 
-def compute_dominance_frontier(nodes: List["Node"]):
+def compute_dominators(nodes: List["Node"]) -> None:
+    """
+    Naive implementation of Cooper, Harvey, Kennedy algo
+    See 'A Simple,Fast Dominance Algorithm'
+
+    Compute strict domniators
+    """
+
+    for n in nodes:
+        n.dominators = set(nodes)
+
+    _compute_dominators(nodes)
+
+    _compute_immediate_dominators(nodes)
+
+
+def compute_dominance_frontier(nodes: List["Node"]) -> None:
     """
     Naive implementation of Cooper, Harvey, Kennedy algo
     See 'A Simple,Fast Dominance Algorithm'
