@@ -7,7 +7,7 @@ if TYPE_CHECKING:
 
 
 class Identifier(ExpressionTyped):
-    def __init__(self, value):
+    def __init__(self, value) -> None:
         super().__init__()
         self._value: "Variable" = value
 
@@ -15,5 +15,5 @@ class Identifier(ExpressionTyped):
     def value(self) -> "Variable":
         return self._value
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self._value)
