@@ -10,16 +10,25 @@ if TYPE_CHECKING:
 
 
 class Literal(Expression):
-    def __init__(self, value, custom_type, subdenomination=None):
+    def __init__(
+        self, value: Union[int, str], custom_type: "Type", subdenomination: Optional[str] = None
+    ) -> None:
         super().__init__()
-        self._value: Union[int, str] = value
+        self._value = value
         self._type = custom_type
-        self._subdenomination: Optional[str] = subdenomination
+        self._subdenomination = subdenomination
 
     @property
     def value(self) -> Union[int, str]:
         return self._value
 
+    @property
+    def converted_value(self) -> Union[int, str]:
+        """Return the value of the literal, accounting for subdenomination e.g. ether"""
+        if self.subdenomination:
+            return convert_subdenomination(self._value, self.subdenomination)
+        return self._value
+
     @property
     def type(self) -> "Type":
         return self._type
@@ -28,9 +37,9 @@ class Literal(Expression):
     def subdenomination(self) -> Optional[str]:
         return self._subdenomination
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.subdenomination:
-            return str(convert_subdenomination(self._value, self.subdenomination))
+            return str(self.converted_value)
 
         if self.type in Int + Uint + Fixed + Ufixed + ["address"]:
             return str(convert_string_to_int(self._value))
@@ -38,7 +47,7 @@ class Literal(Expression):
         # be sure to handle any character
         return str(self._value)
 
-    def __eq__(self, other):
+    def __eq__(self, other) -> bool:
         if not isinstance(other, Literal):
             return False
         return (self.value, self.subdenomination) == (other.value, other.subdenomination)
