@@ -1,19 +1,16 @@
-from typing import TYPE_CHECKING
-
 from slither.core.expressions.expression import Expression
 from slither.core.expressions.expression_typed import ExpressionTyped
 
-if TYPE_CHECKING:
-    from slither.core.solidity_types.type import Type
+from slither.core.solidity_types.type import Type
 
 
 class MemberAccess(ExpressionTyped):
-    def __init__(self, member_name, member_type, expression):
+    def __init__(self, member_name: str, member_type: str, expression: Expression) -> None:
         # assert isinstance(member_type, Type)
         # TODO member_type is not always a Type
         assert isinstance(expression, Expression)
         super().__init__()
-        self._type: "Type" = member_type
+        self._type: Type = member_type
         self._member_name: str = member_name
         self._expression: Expression = expression
 
@@ -26,8 +23,8 @@ class MemberAccess(ExpressionTyped):
         return self._member_name
 
     @property
-    def type(self) -> "Type":
+    def type(self) -> Type:
         return self._type
 
-    def __str__(self):
+    def __str__(self) -> str:
         return str(self.expression) + "." + self.member_name
