@@ -1,9 +1,15 @@
 import logging
+from typing import Union
 from enum import Enum
 
 from slither.core.expressions.expression_typed import ExpressionTyped
 from slither.core.expressions.expression import Expression
 from slither.core.exceptions import SlitherCoreError
+from slither.core.expressions.identifier import Identifier
+from slither.core.expressions.index_access import IndexAccess
+from slither.core.expressions.literal import Literal
+from slither.core.expressions.tuple_expression import TupleExpression
+
 
 logger = logging.getLogger("UnaryOperation")
 
@@ -20,7 +26,7 @@ class UnaryOperationType(Enum):
     MINUS_PRE = 8  # for stuff like uint(-1)
 
     @staticmethod
-    def get_type(operation_type, isprefix):
+    def get_type(operation_type: str, isprefix: bool) -> "UnaryOperationType":
         if isprefix:
             if operation_type == "!":
                 return UnaryOperationType.BANG
@@ -41,9 +47,9 @@ class UnaryOperationType(Enum):
                 return UnaryOperationType.PLUSPLUS_POST
             if operation_type == "--":
                 return UnaryOperationType.MINUSMINUS_POST
-        raise SlitherCoreError("get_type: Unknown operation type {}".format(operation_type))
+        raise SlitherCoreError(f"get_type: Unknown operation type {operation_type}")
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self == UnaryOperationType.BANG:
             return "!"
         if self == UnaryOperationType.TILD:
@@ -62,10 +68,10 @@ class UnaryOperationType(Enum):
         ]:
             return "--"
 
-        raise SlitherCoreError("str: Unknown operation type {}".format(self))
+        raise SlitherCoreError(f"str: Unknown operation type {self}")
 
     @staticmethod
-    def is_prefix(operation_type):
+    def is_prefix(operation_type: "UnaryOperationType") -> bool:
         if operation_type in [
             UnaryOperationType.BANG,
             UnaryOperationType.TILD,
@@ -82,11 +88,15 @@ class UnaryOperationType(Enum):
         ]:
             return False
 
-        raise SlitherCoreError("is_prefix: Unknown operation type {}".format(operation_type))
+        raise SlitherCoreError(f"is_prefix: Unknown operation type {operation_type}")
 
 
 class UnaryOperation(ExpressionTyped):
-    def __init__(self, expression, expression_type):
+    def __init__(
+        self,
+        expression: Union[Literal, Identifier, IndexAccess, TupleExpression],
+        expression_type: UnaryOperationType,
+    ) -> None:
         assert isinstance(expression, Expression)
         super().__init__()
         self._expression: Expression = expression
@@ -114,7 +124,7 @@ class UnaryOperation(ExpressionTyped):
     def is_prefix(self) -> bool:
         return UnaryOperationType.is_prefix(self._type)
 
-    def __str__(self):
+    def __str__(self) -> str:
         if self.is_prefix:
             return str(self.type) + " " + str(self._expression)
         return str(self._expression) + " " + str(self.type)
