@@ -1,6 +1,9 @@
+from typing import List
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import Binary, BinaryType
 from slither.slithir.variables import Constant
+from slither.core.declarations.function_contract import FunctionContract
+from slither.utils.output import Output
 
 
 class ShiftParameterMixup(AbstractDetector):
@@ -13,7 +16,9 @@ class ShiftParameterMixup(AbstractDetector):
     IMPACT = DetectorClassification.HIGH
     CONFIDENCE = DetectorClassification.HIGH
 
-    WIKI = "https://github.com/crytic/slither/wiki/Detector-Documentation#shift-parameter-mixup"
+    WIKI = (
+        "https://github.com/crytic/slither/wiki/Detector-Documentation#incorrect-shift-in-assembly"
+    )
 
     WIKI_TITLE = "Incorrect shift in assembly."
     WIKI_DESCRIPTION = "Detect if the values in a shift operation are reversed"
@@ -34,7 +39,7 @@ The shift statement will right-shift the constant 8 by `a` bits"""
 
     WIKI_RECOMMENDATION = "Swap the order of parameters."
 
-    def _check_function(self, f):
+    def _check_function(self, f: FunctionContract) -> List[Output]:
         results = []
 
         for node in f.nodes:
@@ -50,7 +55,7 @@ The shift statement will right-shift the constant 8 by `a` bits"""
                         results.append(json)
         return results
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         results = []
         for c in self.contracts:
             for f in c.functions:
