@@ -3,8 +3,11 @@
 """
 
 import re
+from typing import List, Optional, Tuple
+
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.formatters.attributes.incorrect_solc import custom_format
+from slither.utils.output import Output
 
 # group:
 # 0: ^ > >= < <= (optional)
@@ -14,7 +17,7 @@ from slither.formatters.attributes.incorrect_solc import custom_format
 # 4: version number
 
 # pylint: disable=anomalous-backslash-in-string
-PATTERN = re.compile("(\^|>|>=|<|<=)?([ ]+)?(\d+)\.(\d+)\.(\d+)")
+PATTERN = re.compile(r"(\^|>|>=|<|<=)?([ ]+)?(\d+)\.(\d+)\.(\d+)")
 
 
 class IncorrectSolc(AbstractDetector):
@@ -40,10 +43,14 @@ We also recommend avoiding complex `pragma` statement."""
     # region wiki_recommendation
     WIKI_RECOMMENDATION = """
 Deploy with any of the following Solidity versions:
-- 0.5.16 - 0.5.17
-- 0.6.11 - 0.6.12
-- 0.7.5 - 0.7.6
-- 0.8.4 - 0.8.7
+- 0.8.18
+
+The recommendations take into account:
+- Risks related to recent releases
+- Risks of complex code generation changes
+- Risks of new language features
+- Risks of known bugs
+
 Use a simple pragma version that allows any of these versions.
 Consider using the latest version of Solidity for testing."""
     # endregion wiki_recommendation
@@ -52,24 +59,14 @@ Consider using the latest version of Solidity for testing."""
     OLD_VERSION_TXT = "allows old versions"
     LESS_THAN_TXT = "uses lesser than"
 
-    TOO_RECENT_VERSION_TXT = "necessitates a version too recent to be trusted. Consider deploying with 0.6.12/0.7.6/0.8.7"
     BUGGY_VERSION_TXT = (
         "is known to contain severe issues (https://solidity.readthedocs.io/en/latest/bugs.html)"
     )
 
     # Indicates the allowed versions. Must be formatted in increasing order.
-    ALLOWED_VERSIONS = [
-        "0.5.16",
-        "0.5.17",
-        "0.6.11",
-        "0.6.12",
-        "0.7.5",
-        "0.7.6",
-        "0.8.4",
-        "0.8.5",
-        "0.8.6",
-        "0.8.7",
-    ]
+    ALLOWED_VERSIONS = ["0.8.18"]
+
+    TOO_RECENT_VERSION_TXT = f"necessitates a version too recent to be trusted. Consider deploying with {'/'.join(ALLOWED_VERSIONS)}."
 
     # Indicates the versions that should not be used.
     BUGGY_VERSIONS = [
@@ -87,7 +84,7 @@ Consider using the latest version of Solidity for testing."""
         "^0.8.8",
     ]
 
-    def _check_version(self, version):
+    def _check_version(self, version: Tuple[str, str, str, str, str]) -> Optional[str]:
         op = version[0]
         if op and op not in [">", ">=", "^"]:
             return self.LESS_THAN_TXT
@@ -100,7 +97,7 @@ Consider using the latest version of Solidity for testing."""
             return self.OLD_VERSION_TXT
         return None
 
-    def _check_pragma(self, version):
+    def _check_pragma(self, version: str) -> Optional[str]:
         if version in self.BUGGY_VERSIONS:
             return self.BUGGY_VERSION_TXT
         versions = PATTERN.findall(version)
@@ -121,7 +118,7 @@ Consider using the latest version of Solidity for testing."""
             return self._check_version(version_left)
         return self.COMPLEX_PRAGMA_TXT
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """
         Detects pragma statements that allow for outdated solc versions.
         :return: Returns the relevant JSON data for the findings.
