@@ -4,8 +4,10 @@ Module detecting unimplemented interfaces
 Collect all the interfaces
 Check for contracts which implement all interface functions but do not explicitly derive from those interfaces.
 """
-
+from typing import List
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.core.declarations.contract import Contract
+from slither.utils.output import Output
 
 
 class MissingInheritance(AbstractDetector):
@@ -42,7 +44,9 @@ contract Something {
     WIKI_RECOMMENDATION = "Inherit from the missing interface or contract."
 
     @staticmethod
-    def detect_unimplemented_interface(contract, interfaces):
+    def detect_unimplemented_interface(
+        contract: Contract, interfaces: List[Contract]
+    ) -> List[Contract]:
         """
         Detects if contract intends to implement one of the interfaces but does not explicitly do so by deriving from it
         :param contract: The contract to check
@@ -50,7 +54,7 @@ contract Something {
         :return: Interfaces likely intended to implement by the contract
         """
 
-        intended_interfaces = []
+        intended_interfaces: List[Contract] = []
         sigs_contract = {f.full_name for f in contract.functions_entry_points}
 
         if not sigs_contract:
@@ -87,7 +91,7 @@ contract Something {
             if not intended_interface_is_subset_parent:
                 # Should not be a subset of an earlier determined intended_interface or derive from it
                 intended_interface_is_subset_intended = False
-                for intended_interface in intended_interfaces:
+                for intended_interface in list(intended_interfaces):
                     sigs_intended_interface = {
                         f.full_name for f in intended_interface.functions_entry_points
                     }
@@ -111,7 +115,7 @@ contract Something {
 
         return intended_interfaces
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect unimplemented interfaces
         Returns:
             list: {'contract'}
