@@ -1,8 +1,13 @@
 """
 Module detecting storage signed integer array bug
 """
+from typing import List
 
-from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.detectors.abstract_detector import (
+    AbstractDetector,
+    DetectorClassification,
+    make_solc_versions,
+)
 from slither.core.cfg.node import NodeType
 from slither.core.solidity_types import ArrayType
 from slither.core.solidity_types.elementary_type import Int, ElementaryType
@@ -10,39 +15,7 @@ from slither.core.variables.local_variable import LocalVariable
 from slither.core.variables.state_variable import StateVariable
 from slither.slithir.operations.assignment import Assignment
 from slither.slithir.operations.init_array import InitArray
-
-vulnerable_solc_versions = [
-    "0.4.7",
-    "0.4.8",
-    "0.4.9",
-    "0.4.10",
-    "0.4.11",
-    "0.4.12",
-    "0.4.13",
-    "0.4.14",
-    "0.4.15",
-    "0.4.16",
-    "0.4.17",
-    "0.4.18",
-    "0.4.19",
-    "0.4.20",
-    "0.4.21",
-    "0.4.22",
-    "0.4.23",
-    "0.4.24",
-    "0.4.25",
-    "0.5.0",
-    "0.5.1",
-    "0.5.2",
-    "0.5.3",
-    "0.5.4",
-    "0.5.5",
-    "0.5.6",
-    "0.5.7",
-    "0.5.8",
-    "0.5.9",
-    "0.5.10",
-]
+from slither.utils.output import Output
 
 
 class StorageSignedIntegerArray(AbstractDetector):
@@ -61,7 +34,7 @@ class StorageSignedIntegerArray(AbstractDetector):
     WIKI_TITLE = "Storage Signed Integer Array"
 
     # region wiki_description
-    WIKI_DESCRIPTION = """`solc` versions `0.4.7`-`0.5.10` contain [a compiler bug](https://blog.ethereum.org/2019/06/25/solidity-storage-array-bugs)
+    WIKI_DESCRIPTION = """`solc` versions `0.4.7`-`0.5.9` contain [a compiler bug](https://blog.ethereum.org/2019/06/25/solidity-storage-array-bugs)
 leading to incorrect values in signed integer arrays."""
     # endregion wiki_description
 
@@ -84,6 +57,8 @@ contract A {
 
     WIKI_RECOMMENDATION = "Use a compiler version >= `0.5.10`."
 
+    VULNERABLE_SOLC_VERSIONS = make_solc_versions(4, 7, 25) + make_solc_versions(5, 0, 9)
+
     @staticmethod
     def _is_vulnerable_type(ir):
         """
@@ -135,13 +110,11 @@ contract A {
         # Return the resulting set of tuples
         return results
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """
         Detect storage signed integer array init/assignment
         """
         results = []
-        if self.compilation_unit.solc_version not in vulnerable_solc_versions:
-            return results
         for contract in self.contracts:
             storage_signed_integer_arrays = self.detect_storage_signed_integer_arrays(contract)
             for function, node in storage_signed_integer_arrays:
