@@ -1,7 +1,11 @@
 """
 Detect incorrect erc721 interface.
 """
+from typing import Any, List, Tuple, Union
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.core.declarations.contract import Contract
+from slither.core.declarations.function_contract import FunctionContract
+from slither.utils.output import Output
 
 
 class IncorrectERC721InterfaceDetection(AbstractDetector):
@@ -20,6 +24,8 @@ class IncorrectERC721InterfaceDetection(AbstractDetector):
 
     WIKI_TITLE = "Incorrect erc721 interface"
     WIKI_DESCRIPTION = "Incorrect return values for `ERC721` functions. A contract compiled with solidity > 0.4.22 interacting with these functions will fail to execute them, as the return value is missing."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract Token{
@@ -28,13 +34,16 @@ contract Token{
 }
 ```
 `Token.ownerOf` does not return an address like `ERC721` expects. Bob deploys the token. Alice creates a contract that interacts with it but assumes a correct `ERC721` interface implementation. Alice's contract is unable to interact with Bob's contract."""
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = (
         "Set the appropriate return values and vtypes for the defined `ERC721` functions."
     )
 
     @staticmethod
-    def incorrect_erc721_interface(signature):
+    def incorrect_erc721_interface(
+        signature: Union[Tuple[str, List[str], List[str]], Tuple[str, List[str], List[Any]]]
+    ) -> bool:
         (name, parameters, returnVars) = signature
 
         # ERC721
@@ -80,7 +89,7 @@ contract Token{
         return False
 
     @staticmethod
-    def detect_incorrect_erc721_interface(contract):
+    def detect_incorrect_erc721_interface(contract: Contract) -> List[Union[FunctionContract, Any]]:
         """Detect incorrect ERC721 interface
 
         Returns:
@@ -99,14 +108,14 @@ contract Token{
         ]
         return functions
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect incorrect erc721 interface
 
         Returns:
             dict: [contract name] = set(str)  events
         """
         results = []
-        for c in self.slither.contracts_derived:
+        for c in self.compilation_unit.contracts_derived:
             functions = IncorrectERC721InterfaceDetection.detect_incorrect_erc721_interface(c)
             if functions:
                 for function in functions:
