@@ -3,8 +3,12 @@ Module detecting suicidal contract
 
 A suicidal contract is an unprotected function that calls selfdestruct
 """
+from typing import List
 
+from slither.core.declarations.contract import Contract
+from slither.core.declarations.function_contract import FunctionContract
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.utils.output import Output
 
 
 class Suicidal(AbstractDetector):
@@ -21,6 +25,8 @@ class Suicidal(AbstractDetector):
 
     WIKI_TITLE = "Suicidal"
     WIKI_DESCRIPTION = "Unprotected call to a function executing `selfdestruct`/`suicide`."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract Suicidal{
@@ -30,11 +36,12 @@ contract Suicidal{
 }
 ```
 Bob calls `kill` and destructs the contract."""
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Protect access to all sensitive functions."
 
     @staticmethod
-    def detect_suicidal_func(func):
+    def detect_suicidal_func(func: FunctionContract) -> bool:
         """Detect if the function is suicidal
 
         Detect the public functions calling suicide/selfdestruct without protection
@@ -57,14 +64,14 @@ Bob calls `kill` and destructs the contract."""
 
         return True
 
-    def detect_suicidal(self, contract):
+    def detect_suicidal(self, contract: Contract) -> List[FunctionContract]:
         ret = []
         for f in contract.functions_declared:
             if self.detect_suicidal_func(f):
                 ret.append(f)
         return ret
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect the suicidal functions"""
         results = []
         for c in self.contracts:
