@@ -13,6 +13,7 @@ from slither.core.declarations.solidity_variables import (
 )
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import Binary, BinaryType
+from slither.utils.output import Output
 
 
 def _timestamp(func: Function) -> List[Node]:
@@ -69,7 +70,7 @@ class Timestamp(AbstractDetector):
     WIKI_EXPLOIT_SCENARIO = """"Bob's contract relies on `block.timestamp` for its randomness. Eve is a miner and manipulates `block.timestamp` to exploit Bob's contract."""
     WIKI_RECOMMENDATION = "Avoid relying on `block.timestamp`."
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """"""
         results = []
 
