@@ -1,9 +1,13 @@
 """
 Module detecting usage of low level calls
 """
-
+from typing import List, Tuple
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import LowLevelCall
+from slither.core.cfg.node import Node
+from slither.core.declarations.contract import Contract
+from slither.core.declarations.function_contract import FunctionContract
+from slither.utils.output import Output
 
 
 class LowLevelCalls(AbstractDetector):
@@ -23,7 +27,7 @@ class LowLevelCalls(AbstractDetector):
     WIKI_RECOMMENDATION = "Avoid low-level calls. Check the call success. If the call is meant for a contract, check for code existence."
 
     @staticmethod
-    def _contains_low_level_calls(node):
+    def _contains_low_level_calls(node: Node) -> bool:
         """
              Check if the node contains Low Level Calls
         Returns:
@@ -31,7 +35,9 @@ class LowLevelCalls(AbstractDetector):
         """
         return any(isinstance(ir, LowLevelCall) for ir in node.irs)
 
-    def detect_low_level_calls(self, contract):
+    def detect_low_level_calls(
+        self, contract: Contract
+    ) -> List[Tuple[FunctionContract, List[Node]]]:
         ret = []
         for f in [f for f in contract.functions if contract == f.contract_declarer]:
             nodes = f.nodes
@@ -40,7 +46,7 @@ class LowLevelCalls(AbstractDetector):
                 ret.append((f, assembly_nodes))
         return ret
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect the functions that use low level calls"""
         results = []
         for c in self.contracts:
@@ -48,6 +54,9 @@ class LowLevelCalls(AbstractDetector):
             for func, nodes in values:
                 info = ["Low level call in ", func, ":\n"]
 
+                # sort the nodes to get deterministic results
+                nodes.sort(key=lambda x: x.node_id)
+
                 for node in nodes:
                     info += ["\t- ", node, "\n"]
 
