@@ -2,11 +2,17 @@
 Module detecting missing events for critical contract parameters set by owners and used in arithmetic
 
 """
+from typing import List, Tuple
 
-from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.analyses.data_dependency.data_dependency import is_tainted
-from slither.slithir.operations.event_call import EventCall
+from slither.core.cfg.node import Node
+from slither.core.declarations.contract import Contract
+from slither.core.declarations.function_contract import FunctionContract
 from slither.core.solidity_types.elementary_type import ElementaryType, Int, Uint
+from slither.core.variables.state_variable import StateVariable
+from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.slithir.operations.event_call import EventCall
+from slither.utils.output import Output
 
 
 class MissingEventsArithmetic(AbstractDetector):
@@ -42,14 +48,16 @@ contract C {
     }    
 }
 ```
-`updateOwner()` has no event, so it is difficult to track off-chain changes in the buy price. 
+`setBuyPrice()` does not emit an event, so it is difficult to track changes in the value of `buyPrice` off-chain. 
 """
     # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Emit an event for critical parameter changes."
 
     @staticmethod
-    def _detect_unprotected_use(contract, sv):
+    def _detect_unprotected_use(
+        contract: Contract, sv: StateVariable
+    ) -> List[Tuple[Node, FunctionContract]]:
         unprotected_functions = [
             function for function in contract.functions_declared if not function.is_protected()
         ]
@@ -60,7 +68,9 @@ contract C {
             if sv in node.state_variables_read
         ]
 
-    def _detect_missing_events(self, contract):
+    def _detect_missing_events(
+        self, contract: Contract
+    ) -> List[Tuple[FunctionContract, List[Tuple[Node, List[Tuple[Node, FunctionContract]]]]]]:
         """
         Detects if critical contract parameters set by owners and used in arithmetic are missing events
         :param contract: The contract to check
@@ -101,7 +111,7 @@ contract C {
                 results.append((function, nodes))
         return results
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect missing events for critical contract parameters set by owners and used in arithmetic
         Returns:
             list: {'(function, node)'}
