@@ -4,6 +4,7 @@ Module detecting unused return values from low level
 from slither.detectors.abstract_detector import DetectorClassification
 from slither.detectors.operations.unused_return_values import UnusedReturnValues
 from slither.slithir.operations import LowLevelCall
+from slither.slithir.operations.operation import Operation
 
 
 class UncheckedLowLevel(UnusedReturnValues):
@@ -20,6 +21,8 @@ class UncheckedLowLevel(UnusedReturnValues):
 
     WIKI_TITLE = "Unchecked low-level calls"
     WIKI_DESCRIPTION = "The return value of a low-level call is not checked."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract MyConc{
@@ -31,10 +34,9 @@ contract MyConc{
 The return value of the low-level call is not checked, so if the call fails, the Ether will be locked in the contract.
 If the low level is used to prevent blocking operations, consider logging failed calls.
     """
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Ensure that the return value of a low-level call is checked or logged."
 
-    _txt_description = "low-level calls"
-
-    def _is_instance(self, ir):  # pylint: disable=no-self-use
+    def _is_instance(self, ir: Operation) -> bool:  # pylint: disable=no-self-use
         return isinstance(ir, LowLevelCall)
