@@ -5,6 +5,7 @@ Module detecting unused return values from send
 from slither.detectors.abstract_detector import DetectorClassification
 from slither.detectors.operations.unused_return_values import UnusedReturnValues
 from slither.slithir.operations import Send
+from slither.slithir.operations.operation import Operation
 
 
 class UncheckedSend(UnusedReturnValues):
@@ -21,6 +22,8 @@ class UncheckedSend(UnusedReturnValues):
 
     WIKI_TITLE = "Unchecked Send"
     WIKI_DESCRIPTION = "The return value of a `send` is not checked."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract MyConc{
@@ -32,10 +35,9 @@ contract MyConc{
 The return value of `send` is not checked, so if the send fails, the Ether will be locked in the contract.
 If `send` is used to prevent blocking operations, consider logging the failed `send`.
     """
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Ensure that the return value of `send` is checked or logged."
 
-    _txt_description = "send calls"
-
-    def _is_instance(self, ir):  # pylint: disable=no-self-use
+    def _is_instance(self, ir: Operation) -> bool:  # pylint: disable=no-self-use
         return isinstance(ir, Send)
