@@ -1,10 +1,16 @@
 """
 Module detecting unused return values from external calls
 """
+from typing import List
 
+from slither.core.cfg.node import Node
+from slither.core.declarations import Function
+from slither.core.declarations.function_contract import FunctionContract
 from slither.core.variables.state_variable import StateVariable
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import HighLevelCall
+from slither.slithir.operations.operation import Operation
+from slither.utils.output import Output
 
 
 class UnusedReturnValues(AbstractDetector):
@@ -23,6 +29,8 @@ class UnusedReturnValues(AbstractDetector):
     WIKI_DESCRIPTION = (
         "The return value of an external call is not stored in a local or state variable."
     )
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract MyConc{
@@ -33,15 +41,23 @@ contract MyConc{
 }
 ```
 `MyConc` calls `add` of `SafeMath`, but does not store the result in `a`. As a result, the computation has no effect."""
+    # endregion wiki_exploit_scenario
 
     WIKI_RECOMMENDATION = "Ensure that all the return values of the function calls are used."
 
-    _txt_description = "external calls"
+    def _is_instance(self, ir: Operation) -> bool:  # pylint: disable=no-self-use
+        return isinstance(ir, HighLevelCall) and (
+            (
+                isinstance(ir.function, Function)
+                and ir.function.solidity_signature
+                not in ["transfer(address,uint256)", "transferFrom(address,address,uint256)"]
+            )
+            or not isinstance(ir.function, Function)
+        )
 
-    def _is_instance(self, ir):  # pylint: disable=no-self-use
-        return isinstance(ir, HighLevelCall)
-
-    def detect_unused_return_values(self, f):  # pylint: disable=no-self-use
+    def detect_unused_return_values(
+        self, f: FunctionContract
+    ) -> List[Node]:  # pylint: disable=no-self-use
         """
             Return the nodes where the return value of a call is unused
         Args:
@@ -64,10 +80,10 @@ contract MyConc{
 
         return [nodes_origin[value].node for value in values_returned]
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect high level calls which return a value that are never used"""
         results = []
-        for c in self.slither.contracts:
+        for c in self.compilation_unit.contracts:
             for f in c.functions + c.modifiers:
                 if f.contract_declarer != c:
                     continue
