@@ -1,5 +1,8 @@
+from typing import List
+
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import Nop
+from slither.utils.output import Output
 
 
 class VoidConstructor(AbstractDetector):
@@ -14,6 +17,8 @@ class VoidConstructor(AbstractDetector):
     WIKI_TITLE = "Void constructor"
     WIKI_DESCRIPTION = "Detect the call to a constructor that is not implemented"
     WIKI_RECOMMENDATION = "Remove the constructor call."
+
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract A{}
@@ -22,8 +27,9 @@ contract B is A{
 }
 ```
 When reading `B`'s constructor definition, we might assume that `A()` initiates the contract, but no code is executed."""
+    # endregion wiki_exploit_scenario
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """"""
         results = []
         for c in self.contracts:
