@@ -1,21 +1,23 @@
 """
 Module detecting assignment of array length
 """
-
+from typing import List, Set
 from slither.detectors.abstract_detector import (
     AbstractDetector,
     DetectorClassification,
     ALL_SOLC_VERSIONS_04,
     ALL_SOLC_VERSIONS_05,
 )
-from slither.core.cfg.node import NodeType
+from slither.core.cfg.node import Node, NodeType
 from slither.slithir.operations import Assignment, Length
 from slither.slithir.variables.reference import ReferenceVariable
 from slither.slithir.operations.binary import Binary
 from slither.analyses.data_dependency.data_dependency import is_tainted
+from slither.core.declarations.contract import Contract
+from slither.utils.output import Output
 
 
-def detect_array_length_assignment(contract):
+def detect_array_length_assignment(contract: Contract) -> Set[Node]:
     """
     Detects and returns all nodes which assign array length.
     :param contract: Contract to detect assignment within.
@@ -110,7 +112,7 @@ Otherwise, thoroughly review the contract to ensure a user-controlled variable c
 
     VULNERABLE_SOLC_VERSIONS = ALL_SOLC_VERSIONS_04 + ALL_SOLC_VERSIONS_05
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """
         Detect array length assignments
         """
