@@ -15,9 +15,10 @@ from slither.slithir.operations import (
 )
 from slither.slithir.variables import ReferenceVariable, TemporaryVariable, TupleVariable
 from slither.slithir.variables.variable import SlithIRVariable
+from slither.utils.output import Output
 
 
-def _remove_states(written: Dict[Variable, Node]):
+def _remove_states(written: Dict[Variable, Node]) -> None:
     for key in list(written.keys()):
         if isinstance(key, StateVariable):
             del written[key]
@@ -27,7 +28,7 @@ def _handle_ir(
     ir: Operation,
     written: Dict[Variable, Node],
     ret: List[Tuple[Variable, Node, Node]],
-):
+) -> None:
     if isinstance(ir, (HighLevelCall, InternalDynamicCall, LowLevelCall)):
         _remove_states(written)
 
@@ -73,7 +74,7 @@ def _detect_write_after_write(
     explored: Set[Node],
     written: Dict[Variable, Node],
     ret: List[Tuple[Variable, Node, Node]],
-):
+) -> None:
     if node in explored:
         return
 
@@ -88,7 +89,7 @@ def _detect_write_after_write(
             _handle_ir(ir, written, ret)
 
     if len(node.sons) > 1:
-        written = dict()
+        written = {}
     for son in node.sons:
         _detect_write_after_write(son, explored, dict(written), ret)
 
@@ -121,14 +122,14 @@ class WriteAfterWrite(AbstractDetector):
 
     WIKI_RECOMMENDATION = """Fix or remove the writes."""
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         results = []
 
         for contract in self.compilation_unit.contracts_derived:
             for function in contract.functions:
                 if function.entry_point:
                     ret = []
-                    _detect_write_after_write(function.entry_point, set(), dict(), ret)
+                    _detect_write_after_write(function.entry_point, set(), {}, ret)
                     for var, node1, node2 in ret:
                         info = [var, " is written in both\n\t", node1, "\n\t", node2, "\n"]
 
