@@ -8,10 +8,16 @@
 
     Only analyze "leaf" contracts (contracts that are not inherited by another contract)
 """
+from typing import List, Tuple
 
+from slither.core.declarations import Function
+from slither.core.declarations.contract import Contract
+from slither.core.variables import Variable
+from slither.core.variables.state_variable import StateVariable
 from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.slithir.operations import InternalCall, LibraryCall
 from slither.slithir.variables import ReferenceVariable
+from slither.utils.output import Output
 
 
 class UninitializedStateVarsDetection(AbstractDetector):
@@ -51,7 +57,7 @@ Initialize all the variables. If a variable is meant to be initialized to zero,
     # endregion wiki_recommendation
 
     @staticmethod
-    def _written_variables(contract):
+    def _written_variables(contract: Contract) -> List[StateVariable]:
         ret = []
         # pylint: disable=too-many-nested-blocks
         for f in contract.all_functions_called + contract.modifiers:
@@ -88,8 +94,8 @@ Initialize all the variables. If a variable is meant to be initialized to zero,
         self.__variables_written_in_proxy = list({v.name for v in variables_written_in_proxy})
         return self.__variables_written_in_proxy
 
-    def _written_variables_in_proxy(self, contract):
-        variables = []
+    def _written_variables_in_proxy(self, contract: Contract) -> List[StateVariable]:
+        variables: List[StateVariable] = []
         if contract.is_upgradeable:
             variables_name_written_in_proxy = self._variable_written_in_proxy()
             if variables_name_written_in_proxy:
@@ -97,18 +103,20 @@ Initialize all the variables. If a variable is meant to be initialized to zero,
                     contract.get_state_variable_from_name(v)
                     for v in variables_name_written_in_proxy
                 ]
-                variables_in_contract = [v for v in variables_in_contract if v]
-                variables += variables_in_contract
+                variables += [v for v in variables_in_contract if v]
         return list(set(variables))
 
     @staticmethod
-    def _read_variables(contract):
+    def _read_variables(contract: Contract) -> List[StateVariable]:
         ret = []
-        for f in contract.all_functions_called + contract.modifiers:
-            ret += f.state_variables_read
+        for f in contract.all_functions_called:
+            if isinstance(f, Function):
+                ret += f.state_variables_read
+        for m in contract.modifiers:
+            ret += m.state_variables_read
         return ret
 
-    def _detect_uninitialized(self, contract):
+    def _detect_uninitialized(self, contract: Contract) -> List[Tuple[Variable, List[Function]]]:
         written_variables = self._written_variables(contract)
         written_variables += self._written_variables_in_proxy(contract)
         read_variables = self._read_variables(contract)
@@ -120,7 +128,7 @@ Initialize all the variables. If a variable is meant to be initialized to zero,
             and variable in read_variables
         ]
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect uninitialized state variables
 
         Recursively visit the calls
