@@ -1,15 +1,19 @@
 """
 Module detecting unused state variables
 """
+from typing import List, Optional
 
-from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
+from slither.core.compilation_unit import SlitherCompilationUnit
+from slither.core.declarations.contract import Contract
 from slither.core.solidity_types import ArrayType
-from slither.visitors.expression.export_values import ExportValues
 from slither.core.variables.state_variable import StateVariable
+from slither.detectors.abstract_detector import AbstractDetector, DetectorClassification
 from slither.formatters.variables.unused_state_variables import custom_format
+from slither.utils.output import Output
+from slither.visitors.expression.export_values import ExportValues
 
 
-def detect_unused(contract):
+def detect_unused(contract: Contract) -> Optional[List[StateVariable]]:
     if contract.is_signature_only():
         return None
     # Get all the variables read in all the functions and modifiers
@@ -47,17 +51,17 @@ class UnusedStateVars(AbstractDetector):
     IMPACT = DetectorClassification.INFORMATIONAL
     CONFIDENCE = DetectorClassification.HIGH
 
-    WIKI = "https://github.com/crytic/slither/wiki/Detector-Documentation#unused-state-variables"
+    WIKI = "https://github.com/crytic/slither/wiki/Detector-Documentation#unused-state-variable"
 
     WIKI_TITLE = "Unused state variable"
     WIKI_DESCRIPTION = "Unused state variable."
     WIKI_EXPLOIT_SCENARIO = ""
     WIKI_RECOMMENDATION = "Remove unused state variables."
 
-    def _detect(self):
+    def _detect(self) -> List[Output]:
         """Detect unused state variables"""
         results = []
-        for c in self.slither.contracts_derived:
+        for c in self.compilation_unit.contracts_derived:
             unusedVars = detect_unused(c)
             if unusedVars:
                 for var in unusedVars:
@@ -68,5 +72,5 @@ class UnusedStateVars(AbstractDetector):
         return results
 
     @staticmethod
-    def _format(slither, result):
-        custom_format(slither, result)
+    def _format(compilation_unit: SlitherCompilationUnit, result):
+        custom_format(compilation_unit, result)
