@@ -30,9 +30,6 @@ class PrinterInheritance(AbstractPrinter):
         """
         info = "Inheritance\n"
 
-        if not self.contracts:
-            return []
-
         info += blue("Child_Contract -> ") + green("Immediate_Base_Contracts")
         info += green(" [Not_Immediate_Base_Contracts]")
 
