@@ -1,23 +1,22 @@
 """
     Module printing summary of the contract
 """
+from slither.core.declarations import Function
+from slither.core.source_mapping.source_mapping import Source
 from slither.printers.abstract_printer import AbstractPrinter
 from slither.utils import output
 
 
+def _get_source_code(cst: Function) -> str:
+    src_mapping: Source = cst.source_mapping
+    return " " * src_mapping.starting_column + src_mapping.content
+
+
 class ConstructorPrinter(AbstractPrinter):
     WIKI = "https://github.com/crytic/slither/wiki/Printer-documentation#constructor-calls"
     ARGUMENT = "constructor-calls"
     HELP = "Print the constructors executed"
 
-    def _get_soruce_code(self, cst):
-        src_mapping = cst.source_mapping
-        content = self.slither.source_code[src_mapping["filename_absolute"]]
-        start = src_mapping["start"]
-        end = src_mapping["start"] + src_mapping["length"]
-        initial_space = src_mapping["starting_column"]
-        return " " * initial_space + content[start:end]
-
     def output(self, _filename):
         info = ""
         for contract in self.slither.contracts_derived:
@@ -26,12 +25,12 @@ class ConstructorPrinter(AbstractPrinter):
             cst = contract.constructors_declared
             if cst:
                 stack_name.append(contract.name)
-                stack_definition.append(self._get_soruce_code(cst))
+                stack_definition.append(_get_source_code(cst))
             for inherited_contract in contract.inheritance:
                 cst = inherited_contract.constructors_declared
                 if cst:
                     stack_name.append(inherited_contract.name)
-                    stack_definition.append(self._get_soruce_code(cst))
+                    stack_definition.append(_get_source_code(cst))
 
             if len(stack_name) > 0:
 
