@@ -9,14 +9,14 @@ def _print_function(function: Function) -> str:
     txt = ""
     for node in function.nodes:
         if node.expression:
-            txt += "\t\tExpression: {}\n".format(node.expression)
+            txt += f"\t\tExpression: {node.expression}\n"
             txt += "\t\tIRs:\n"
             for ir in node.irs:
-                txt += "\t\t\t{}\n".format(ir)
+                txt += f"\t\t\t{ir}\n"
         elif node.irs:
             txt += "\t\tIRs:\n"
             for ir in node.irs:
-                txt += "\t\t\t{}\n".format(ir)
+                txt += f"\t\t\t{ir}\n"
     return txt
 
 
@@ -38,15 +38,15 @@ class PrinterSlithIR(AbstractPrinter):
             for contract in compilation_unit.contracts:
                 if contract.is_top_level:
                     continue
-                txt += "Contract {}\n".format(contract.name)
+                txt += f"Contract {contract.name}\n"
                 for function in contract.functions:
                     txt += f'\tFunction {function.canonical_name} {"" if function.is_shadowed else "(*)"}\n'
                     txt += _print_function(function)
                 for modifier in contract.modifiers:
-                    txt += "\tModifier {}\n".format(modifier.canonical_name)
+                    txt += f"\tModifier {modifier.canonical_name}\n"
                     txt += _print_function(modifier)
             if compilation_unit.functions_top_level:
-                txt += "Top level functions"
+                txt += "Top level functions\n"
             for function in compilation_unit.functions_top_level:
                 txt += f"\tFunction {function.canonical_name}\n"
                 txt += _print_function(function)
