@@ -1,6 +1,6 @@
 import logging
 from pathlib import Path
-from typing import List, TYPE_CHECKING, Union, Optional
+from typing import Any, List, TYPE_CHECKING, Union, Optional
 
 # pylint: disable= too-many-lines,import-outside-toplevel,too-many-branches,too-many-statements,too-many-nested-blocks
 from slither.core.declarations import (
@@ -15,6 +15,7 @@ from slither.core.declarations import (
 )
 from slither.core.declarations.custom_error import CustomError
 from slither.core.declarations.function_contract import FunctionContract
+from slither.core.declarations.function_top_level import FunctionTopLevel
 from slither.core.declarations.solidity_import_placeholder import SolidityImportPlaceHolder
 from slither.core.declarations.solidity_variables import SolidityCustomRevert
 from slither.core.expressions import Identifier, Literal
@@ -33,7 +34,7 @@ from slither.core.solidity_types.elementary_type import (
     MaxValues,
 )
 from slither.core.solidity_types.type import Type
-from slither.core.solidity_types.type_alias import TypeAlias
+from slither.core.solidity_types.type_alias import TypeAliasTopLevel, TypeAlias
 from slither.core.variables.function_type_variable import FunctionTypeVariable
 from slither.core.variables.state_variable import StateVariable
 from slither.core.variables.variable import Variable
@@ -60,7 +61,6 @@ from slither.slithir.operations import (
     NewElementaryType,
     NewStructure,
     OperationWithLValue,
-    Push,
     Return,
     Send,
     SolidityCall,
@@ -83,15 +83,36 @@ from slither.slithir.variables import TupleVariable
 from slither.utils.function import get_function_id
 from slither.utils.type import export_nested_types_from_variable
 from slither.visitors.slithir.expression_to_slithir import ExpressionToSlithIR
+import slither.core.declarations.contract
+import slither.core.declarations.function
+import slither.core.solidity_types.elementary_type
+import slither.core.solidity_types.function_type
+import slither.core.solidity_types.user_defined_type
+import slither.slithir.operations.assignment
+import slither.slithir.operations.binary
+import slither.slithir.operations.call
+import slither.slithir.operations.high_level_call
+import slither.slithir.operations.index
+import slither.slithir.operations.init_array
+import slither.slithir.operations.internal_call
+import slither.slithir.operations.length
+import slither.slithir.operations.library_call
+import slither.slithir.operations.low_level_call
+import slither.slithir.operations.member
+import slither.slithir.operations.operation
+import slither.slithir.operations.send
+import slither.slithir.operations.solidity_call
+import slither.slithir.operations.transfer
+import slither.slithir.variables.temporary
+from slither.core.expressions.expression import Expression
 
 if TYPE_CHECKING:
     from slither.core.cfg.node import Node
-    from slither.core.compilation_unit import SlitherCompilationUnit
 
 logger = logging.getLogger("ConvertToIR")
 
 
-def convert_expression(expression, node):
+def convert_expression(expression: Expression, node: "Node") -> List[Any]:
     # handle standlone expression
     # such as return true;
     from slither.core.cfg.node import NodeType
@@ -143,7 +164,7 @@ def convert_expression(expression, node):
 ###################################################################################
 
 
-def is_value(ins):
+def is_value(ins: Operation) -> bool:
     if isinstance(ins, TmpCall):
         if isinstance(ins.ori, Member):
             if ins.ori.variable_right == "value":
@@ -151,7 +172,7 @@ def is_value(ins):
     return False
 
 
-def is_gas(ins):
+def is_gas(ins: Operation) -> bool:
     if isinstance(ins, TmpCall):
         if isinstance(ins.ori, Member):
             if ins.ori.variable_right == "gas":
@@ -159,7 +180,7 @@ def is_gas(ins):
     return False
 
 
-def _fits_under_integer(val: int, can_be_int: bool, can_be_uint) -> List[str]:
+def _fits_under_integer(val: int, can_be_int: bool, can_be_uint: bool) -> List[str]:
     """
     Return the list of uint/int that can contain val
 
@@ -200,18 +221,22 @@ def _fits_under_byte(val: Union[int, str]) -> List[str]:
     return [f"bytes{f}" for f in range(length, 33)] + ["bytes"]
 
 
-def _find_function_from_parameter(ir: Call, candidates: List[Function]) -> Optional[Function]:
+def _find_function_from_parameter(
+    arguments: List[Variable], candidates: List[Function], full_comparison: bool
+) -> Optional[Function]:
     """
-    Look for a function in candidates that can be the target of the ir's call
+    Look for a function in candidates that can be the target based on the ir's call arguments
 
     Try the implicit type conversion for uint/int/bytes. Constant values can be both uint/int
-    While variables stick to their base type, but can changed the size
+    While variables stick to their base type, but can changed the size.
+    If full_comparison is True it will do a comparison of all the arguments regardless if
+    the candidate remained is one.
 
-    :param ir:
+    :param arguments:
     :param candidates:
+    :param full_comparison:
     :return:
     """
-    arguments = ir.arguments
     type_args: List[str]
     for idx, arg in enumerate(arguments):
         if isinstance(arg, (list,)):
@@ -259,7 +284,7 @@ def _find_function_from_parameter(ir: Call, candidates: List[Function]) -> Optio
                     not_found = False
                     candidates_kept.append(candidate)
 
-            if len(candidates_kept) == 1:
+            if len(candidates_kept) == 1 and not full_comparison:
                 return candidates_kept[0]
         candidates = candidates_kept
     if len(candidates) == 1:
@@ -267,7 +292,7 @@ def _find_function_from_parameter(ir: Call, candidates: List[Function]) -> Optio
     return None
 
 
-def is_temporary(ins):
+def is_temporary(ins: Operation) -> bool:
     return isinstance(
         ins,
         (Argument, TmpNewElementaryType, TmpNewContract, TmpNewArray, TmpNewStructure),
@@ -296,7 +321,7 @@ def _make_function_type(func: Function) -> FunctionType:
 ###################################################################################
 
 
-def integrate_value_gas(result):
+def integrate_value_gas(result: List[Operation]) -> List[Operation]:
     """
     Integrate value and gas temporary arguments to call instruction
     """
@@ -375,7 +400,7 @@ def integrate_value_gas(result):
 ###################################################################################
 
 
-def propagate_type_and_convert_call(result, node):
+def propagate_type_and_convert_call(result: List[Operation], node: "Node") -> List[Operation]:
     """
     Propagate the types variables and convert tmp call to real call operation
     """
@@ -451,19 +476,25 @@ def propagate_type_and_convert_call(result, node):
     return result
 
 
-def _convert_type_contract(ir, compilation_unit: "SlitherCompilationUnit"):
+def _convert_type_contract(ir: Member) -> Assignment:
     assert isinstance(ir.variable_left.type, TypeInformation)
     contract = ir.variable_left.type.type
 
+    scope = ir.node.file_scope
+
     if ir.variable_right == "creationCode":
-        bytecode = compilation_unit.crytic_compile_compilation_unit.bytecode_init(contract.name)
+        bytecode = scope.bytecode_init(
+            ir.node.compilation_unit.crytic_compile_compilation_unit, contract.name
+        )
         assignment = Assignment(ir.lvalue, Constant(str(bytecode)), ElementaryType("bytes"))
         assignment.set_expression(ir.expression)
         assignment.set_node(ir.node)
         assignment.lvalue.set_type(ElementaryType("bytes"))
         return assignment
     if ir.variable_right == "runtimeCode":
-        bytecode = compilation_unit.crytic_compile_compilation_unit.bytecode_runtime(contract.name)
+        bytecode = scope.bytecode_runtime(
+            ir.node.compilation_unit.crytic_compile_compilation_unit, contract.name
+        )
         assignment = Assignment(ir.lvalue, Constant(str(bytecode)), ElementaryType("bytes"))
         assignment.set_expression(ir.expression)
         assignment.set_node(ir.node)
@@ -494,11 +525,13 @@ def _convert_type_contract(ir, compilation_unit: "SlitherCompilationUnit"):
     raise SlithIRError(f"type({contract.name}).{ir.variable_right} is unknown")
 
 
-def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
+def propagate_types(ir: Operation, node: "Node"):  # pylint: disable=too-many-locals
     # propagate the type
     node_function = node.function
     using_for = (
-        node_function.contract.using_for if isinstance(node_function, FunctionContract) else {}
+        node_function.contract.using_for_complete
+        if isinstance(node_function, FunctionContract)
+        else {}
     )
     if isinstance(ir, OperationWithLValue):
         # Force assignment in case of missing previous correct type
@@ -525,9 +558,9 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                     if can_be_solidity_func(ir):
                         return convert_to_solidity_func(ir)
 
-                # convert library
+                # convert library or top level function
                 if t in using_for or "*" in using_for:
-                    new_ir = convert_to_library(ir, node, using_for)
+                    new_ir = convert_to_library_or_top_level(ir, node, using_for)
                     if new_ir:
                         return new_ir
 
@@ -535,16 +568,17 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                     # UserdefinedType
                     t_type = t.type
                     if isinstance(t_type, Contract):
-                        contract = node.file_scope.get_contract_from_name(t_type.name)
-                        return convert_type_of_high_and_internal_level_call(ir, contract)
+                        # the target contract of the IR is the t_type (the destination of the call)
+                        return convert_type_of_high_and_internal_level_call(ir, t_type)
 
                 # Convert HighLevelCall to LowLevelCall
                 if (isinstance(t, ElementaryType) and t.name == "address") or (
                     isinstance(t, TypeAlias) and t.underlying_type.name == "address"
                 ):
-                    # Cannot be a top level function with this.
-                    assert isinstance(node_function, FunctionContract)
                     if ir.destination.name == "this":
+                        # Cannot be a top level function with this.
+                        assert isinstance(node_function, FunctionContract)
+                        # the target contract is the contract itself
                         return convert_type_of_high_and_internal_level_call(
                             ir, node_function.contract
                         )
@@ -579,6 +613,7 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                     function_contract = (
                         func.contract if isinstance(func, FunctionContract) else None
                     )
+                    # the target contract might be None if its a top level function
                     convert_type_of_high_and_internal_level_call(ir, function_contract)
                 return_type = ir.function.return_type
                 if return_type:
@@ -652,7 +687,24 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                 if ir.variable_right == "selector" and isinstance(ir.variable_left, (CustomError)):
                     assignment = Assignment(
                         ir.lvalue,
-                        Constant(str(get_function_id(ir.variable_left.solidity_signature))),
+                        Constant(
+                            str(get_function_id(ir.variable_left.solidity_signature)),
+                            ElementaryType("bytes4"),
+                        ),
+                        ElementaryType("bytes4"),
+                    )
+                    assignment.set_expression(ir.expression)
+                    assignment.set_node(ir.node)
+                    assignment.lvalue.set_type(ElementaryType("bytes4"))
+                    return assignment
+
+                if isinstance(ir.variable_right, (CustomError)):
+                    assignment = Assignment(
+                        ir.lvalue,
+                        Constant(
+                            str(get_function_id(ir.variable_left.solidity_signature)),
+                            ElementaryType("bytes4"),
+                        ),
                         ElementaryType("bytes4"),
                     )
                     assignment.set_expression(ir.expression)
@@ -674,7 +726,7 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                 if isinstance(ir.variable_left, TemporaryVariable) and isinstance(
                     ir.variable_left.type, TypeInformation
                 ):
-                    return _convert_type_contract(ir, node.function.compilation_unit)
+                    return _convert_type_contract(ir)
                 left = ir.variable_left
                 t = None
                 ir_func = ir.function
@@ -724,7 +776,7 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                             if f:
                                 ir.lvalue.set_type(f)
                             else:
-                                # Allow propgation for variable access through contract's nale
+                                # Allow propgation for variable access through contract's name
                                 # like Base_contract.my_variable
                                 v = next(
                                     (
@@ -745,9 +797,6 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
                 ir.lvalue.set_type(ir.type)
             elif isinstance(ir, NewStructure):
                 ir.lvalue.set_type(UserDefinedType(ir.structure))
-            elif isinstance(ir, Push):
-                # No change required
-                pass
             elif isinstance(ir, Send):
                 ir.lvalue.set_type(ElementaryType("bool"))
             elif isinstance(ir, SolidityCall):
@@ -785,7 +834,10 @@ def propagate_types(ir, node: "Node"):  # pylint: disable=too-many-locals
     return None
 
 
-def extract_tmp_call(ins: TmpCall, contract: Optional[Contract]):  # pylint: disable=too-many-locals
+# pylint: disable=too-many-locals
+def extract_tmp_call(
+    ins: TmpCall, contract: Optional[Contract]
+) -> slither.slithir.operations.call.Call:
     assert isinstance(ins, TmpCall)
     if isinstance(ins.called, Variable) and isinstance(ins.called.type, FunctionType):
         # If the call is made to a variable member, where the member is this
@@ -879,7 +931,9 @@ def extract_tmp_call(ins: TmpCall, contract: Optional[Contract]):  # pylint: dis
             # }
             node_func = ins.node.function
             using_for = (
-                node_func.contract.using_for if isinstance(node_func, FunctionContract) else {}
+                node_func.contract.using_for_complete
+                if isinstance(node_func, FunctionContract)
+                else {}
             )
 
             targeted_libraries = (
@@ -892,10 +946,14 @@ def extract_tmp_call(ins: TmpCall, contract: Optional[Contract]):  # pylint: dis
                     lib_contract_type.type, Contract
                 ):
                     continue
-                lib_contract = lib_contract_type.type
-                for lib_func in lib_contract.functions:
-                    if lib_func.name == ins.ori.variable_right:
-                        candidates.append(lib_func)
+                if isinstance(lib_contract_type, FunctionContract):
+                    # Using for with list of functions, this is the function called
+                    candidates.append(lib_contract_type)
+                else:
+                    lib_contract = lib_contract_type.type
+                    for lib_func in lib_contract.functions:
+                        if lib_func.name == ins.ori.variable_right:
+                            candidates.append(lib_func)
 
             if len(candidates) == 1:
                 lib_func = candidates[0]
@@ -1080,7 +1138,7 @@ def extract_tmp_call(ins: TmpCall, contract: Optional[Contract]):  # pylint: dis
 ###################################################################################
 
 
-def can_be_low_level(ir):
+def can_be_low_level(ir: HighLevelCall) -> bool:
     return ir.function_name in [
         "transfer",
         "send",
@@ -1091,7 +1149,9 @@ def can_be_low_level(ir):
     ]
 
 
-def convert_to_low_level(ir):
+def convert_to_low_level(
+    ir: HighLevelCall,
+) -> Union[Send, LowLevelCall, Transfer,]:
     """
     Convert to a transfer/send/or low level call
     The funciton assume to receive a correct IR
@@ -1131,7 +1191,7 @@ def convert_to_low_level(ir):
     raise SlithIRError(f"Incorrect conversion to low level {ir}")
 
 
-def can_be_solidity_func(ir) -> bool:
+def can_be_solidity_func(ir: HighLevelCall) -> bool:
     if not isinstance(ir, HighLevelCall):
         return False
     return ir.destination.name == "abi" and ir.function_name in [
@@ -1139,11 +1199,14 @@ def can_be_solidity_func(ir) -> bool:
         "encodePacked",
         "encodeWithSelector",
         "encodeWithSignature",
+        "encodeCall",
         "decode",
     ]
 
 
-def convert_to_solidity_func(ir):
+def convert_to_solidity_func(
+    ir: HighLevelCall,
+) -> SolidityCall:
     """
     Must be called after can_be_solidity_func
     :param ir:
@@ -1179,7 +1242,9 @@ def convert_to_solidity_func(ir):
     return new_ir
 
 
-def convert_to_push_expand_arr(ir, node, ret):
+def convert_to_push_expand_arr(
+    ir: HighLevelCall, node: "Node", ret: List[Any]
+) -> TemporaryVariable:
     arr = ir.destination
 
     length = ReferenceVariable(node)
@@ -1214,7 +1279,18 @@ def convert_to_push_expand_arr(ir, node, ret):
     return length_val
 
 
-def convert_to_push_set_val(ir, node, length_val, ret):
+def convert_to_push_set_val(
+    ir: HighLevelCall,
+    node: "Node",
+    length_val: TemporaryVariable,
+    ret: List[
+        Union[
+            Length,
+            Assignment,
+            Binary,
+        ]
+    ],
+) -> None:
     arr = ir.destination
 
     new_type = ir.destination.type.type
@@ -1249,7 +1325,17 @@ def convert_to_push_set_val(ir, node, length_val, ret):
         ret.append(ir_assign_value)
 
 
-def convert_to_push(ir, node):
+def convert_to_push(
+    ir: slither.slithir.operations.high_level_call.HighLevelCall, node: "Node"
+) -> List[
+    Union[
+        slither.slithir.operations.length.Length,
+        slither.slithir.operations.assignment.Assignment,
+        slither.slithir.operations.binary.Binary,
+        slither.slithir.operations.index.Index,
+        slither.slithir.operations.init_array.InitArray,
+    ]
+]:
     """
     Convert a call to a series of operations to push a new value onto the array
 
@@ -1323,9 +1409,42 @@ def convert_to_pop(ir, node):
     return ret
 
 
-def look_for_library(contract, ir, using_for, t):
+def look_for_library_or_top_level(
+    contract: Contract,
+    ir: HighLevelCall,
+    using_for,
+    t: Union[
+        UserDefinedType,
+        ElementaryType,
+        str,
+        TypeAliasTopLevel,
+    ],
+) -> Optional[Union[LibraryCall, InternalCall,]]:
     for destination in using_for[t]:
-        lib_contract = contract.file_scope.get_contract_from_name(str(destination))
+        if isinstance(destination, FunctionTopLevel) and destination.name == ir.function_name:
+            arguments = [ir.destination] + ir.arguments
+            if (
+                len(destination.parameters) == len(arguments)
+                and _find_function_from_parameter(arguments, [destination], True) is not None
+            ):
+                internalcall = InternalCall(destination, ir.nbr_arguments, ir.lvalue, ir.type_call)
+                internalcall.set_expression(ir.expression)
+                internalcall.set_node(ir.node)
+                internalcall.arguments = [ir.destination] + ir.arguments
+                return_type = internalcall.function.return_type
+                if return_type:
+                    if len(return_type) == 1:
+                        internalcall.lvalue.set_type(return_type[0])
+                    elif len(return_type) > 1:
+                        internalcall.lvalue.set_type(return_type)
+                else:
+                    internalcall.lvalue = None
+                return internalcall
+
+        if isinstance(destination, FunctionContract) and destination.contract.is_library:
+            lib_contract = destination.contract
+        else:
+            lib_contract = contract.file_scope.get_contract_from_name(str(destination))
         if lib_contract:
             lib_call = LibraryCall(
                 lib_contract,
@@ -1345,26 +1464,33 @@ def look_for_library(contract, ir, using_for, t):
     return None
 
 
-def convert_to_library(ir, node, using_for):
+def convert_to_library_or_top_level(
+    ir: HighLevelCall, node: "Node", using_for
+) -> Optional[Union[LibraryCall, InternalCall,]]:
     # We use contract_declarer, because Solidity resolve the library
     # before resolving the inheritance.
     # Though we could use .contract as libraries cannot be shadowed
     contract = node.function.contract_declarer
     t = ir.destination.type
     if t in using_for:
-        new_ir = look_for_library(contract, ir, using_for, t)
+        new_ir = look_for_library_or_top_level(contract, ir, using_for, t)
         if new_ir:
             return new_ir
 
     if "*" in using_for:
-        new_ir = look_for_library(contract, ir, using_for, "*")
+        new_ir = look_for_library_or_top_level(contract, ir, using_for, "*")
         if new_ir:
             return new_ir
 
     return None
 
 
-def get_type(t):
+def get_type(
+    t: Union[
+        UserDefinedType,
+        ElementaryType,
+    ]
+) -> str:
     """
     Convert a type to a str
     If the instance is a Contract, return 'address' instead
@@ -1383,7 +1509,7 @@ def _can_be_implicitly_converted(source: str, target: str) -> bool:
     return source == target
 
 
-def convert_type_library_call(ir: HighLevelCall, lib_contract: Contract):
+def convert_type_library_call(ir: HighLevelCall, lib_contract: Contract) -> Optional[LibraryCall]:
     func = None
     candidates = [
         f
@@ -1403,7 +1529,7 @@ def convert_type_library_call(ir: HighLevelCall, lib_contract: Contract):
         # TODO: handle collision with multiple state variables/functions
         func = lib_contract.get_state_variable_from_name(ir.function_name)
     if func is None and candidates:
-        func = _find_function_from_parameter(ir, candidates)
+        func = _find_function_from_parameter(ir.arguments, candidates, False)
 
     # In case of multiple binding to the same type
     # TODO: this part might not be needed with _find_function_from_parameter
@@ -1473,7 +1599,19 @@ def _convert_to_structure_to_list(return_type: Type) -> List[Type]:
     return [return_type.type]
 
 
-def convert_type_of_high_and_internal_level_call(ir: Operation, contract: Optional[Contract]):
+def convert_type_of_high_and_internal_level_call(
+    ir: Operation, contract: Optional[Contract]
+) -> Optional[Operation]:
+    """
+    Convert the IR type based on heuristic
+
+    Args:
+        ir: target
+        contract: optional contract. This should be the target of the IR. It will be used to look up potential functions
+
+    Returns:
+        Potential new IR
+    """
     func = None
     if isinstance(ir, InternalCall):
         candidates: List[Function]
@@ -1499,7 +1637,7 @@ def convert_type_of_high_and_internal_level_call(ir: Operation, contract: Option
                         if f.name == ir.function_name and len(f.parameters) == len(ir.arguments)
                     ]
 
-        func = _find_function_from_parameter(ir, candidates)
+        func = _find_function_from_parameter(ir.arguments, candidates, False)
 
         if not func:
             assert contract
@@ -1507,7 +1645,6 @@ def convert_type_of_high_and_internal_level_call(ir: Operation, contract: Option
     else:
         assert isinstance(ir, HighLevelCall)
         assert contract
-
         candidates = [
             f
             for f in contract.functions
@@ -1515,14 +1652,13 @@ def convert_type_of_high_and_internal_level_call(ir: Operation, contract: Option
             and not f.is_shadowed
             and len(f.parameters) == len(ir.arguments)
         ]
-
         if len(candidates) == 1:
             func = candidates[0]
         if func is None:
             # TODO: handle collision with multiple state variables/functions
             func = contract.get_state_variable_from_name(ir.function_name)
         if func is None and candidates:
-            func = _find_function_from_parameter(ir, candidates)
+            func = _find_function_from_parameter(ir.arguments, candidates, False)
 
     # lowlelvel lookup needs to be done at last step
     if not func:
@@ -1584,7 +1720,7 @@ def convert_type_of_high_and_internal_level_call(ir: Operation, contract: Option
 ###################################################################################
 
 
-def find_references_origin(irs):
+def find_references_origin(irs: List[Operation]) -> None:
     """
     Make lvalue of each Index, Member operation
     points to the left variable
@@ -1621,7 +1757,7 @@ def remove_temporary(result):
     return result
 
 
-def remove_unused(result):
+def remove_unused(result: List[Operation]) -> List[Operation]:
     removed = True
 
     if not result:
@@ -1668,7 +1804,7 @@ def remove_unused(result):
 ###################################################################################
 
 
-def convert_constant_types(irs):
+def convert_constant_types(irs: List[Operation]) -> None:
     """
     late conversion of uint -> type for constant (Literal)
     :param irs:
@@ -1744,7 +1880,7 @@ def convert_constant_types(irs):
 ###################################################################################
 
 
-def convert_delete(irs):
+def convert_delete(irs: List[Operation]) -> None:
     """
     Convert the lvalue of the Delete to point to the variable removed
     This can only be done after find_references_origin is called
@@ -1765,7 +1901,7 @@ def convert_delete(irs):
 ###################################################################################
 
 
-def _find_source_mapping_references(irs: List[Operation]):
+def _find_source_mapping_references(irs: List[Operation]) -> None:
     for ir in irs:
 
         if isinstance(ir, NewContract):
@@ -1780,7 +1916,7 @@ def _find_source_mapping_references(irs: List[Operation]):
 ###################################################################################
 
 
-def apply_ir_heuristics(irs, node):
+def apply_ir_heuristics(irs: List[Operation], node: "Node") -> List[Operation]:
     """
     Apply a set of heuristic to improve slithIR
     """
