@@ -1,9 +1,15 @@
+from typing import List, Union
 from slither.slithir.operations.lvalue import OperationWithLValue
 from slither.slithir.utils.utils import is_valid_rvalue
+from slither.slithir.variables.constant import Constant
+from slither.slithir.variables.temporary import TemporaryVariable
+from slither.slithir.variables.temporary_ssa import TemporaryVariableSSA
 
 
 class InitArray(OperationWithLValue):
-    def __init__(self, init_values, lvalue):
+    def __init__(
+        self, init_values: List[Constant], lvalue: Union[TemporaryVariableSSA, TemporaryVariable]
+    ) -> None:
         # init_values can be an array of n dimension
         # reduce was removed in py3
         super().__init__()
@@ -24,11 +30,11 @@ class InitArray(OperationWithLValue):
         self._lvalue = lvalue
 
     @property
-    def read(self):
+    def read(self) -> List[Constant]:
         return self._unroll(self.init_values)
 
     @property
-    def init_values(self):
+    def init_values(self) -> List[Constant]:
         return list(self._init_values)
 
     def __str__(self):
@@ -38,4 +44,4 @@ class InitArray(OperationWithLValue):
             return str(elem)
 
         init_values = convert(self.init_values)
-        return "{}({}) =  {}".format(self.lvalue, self.lvalue.type, init_values)
+        return f"{self.lvalue}({self.lvalue.type}) =  {init_values}"
