@@ -1,14 +1,25 @@
+from typing import List, Optional, Union
 from slither.core.solidity_types import FunctionType
 from slither.core.variables.variable import Variable
 from slither.slithir.operations.call import Call
 from slither.slithir.operations.lvalue import OperationWithLValue
 from slither.slithir.utils.utils import is_valid_lvalue
+from slither.core.variables.local_variable import LocalVariable
+from slither.slithir.variables.constant import Constant
+from slither.slithir.variables.local_variable import LocalIRVariable
+from slither.slithir.variables.temporary import TemporaryVariable
+from slither.slithir.variables.temporary_ssa import TemporaryVariableSSA
 
 
 class InternalDynamicCall(
     Call, OperationWithLValue
 ):  # pylint: disable=too-many-instance-attributes
-    def __init__(self, lvalue, function, function_type):
+    def __init__(
+        self,
+        lvalue: Optional[Union[TemporaryVariableSSA, TemporaryVariable]],
+        function: Union[LocalVariable, LocalIRVariable],
+        function_type: FunctionType,
+    ) -> None:
         assert isinstance(function_type, FunctionType)
         assert isinstance(function, Variable)
         assert is_valid_lvalue(lvalue) or lvalue is None
@@ -22,15 +33,15 @@ class InternalDynamicCall(
         self._call_gas = None
 
     @property
-    def read(self):
+    def read(self) -> List[Union[Constant, LocalIRVariable, LocalVariable]]:
         return self._unroll(self.arguments) + [self.function]
 
     @property
-    def function(self):
+    def function(self) -> Union[LocalVariable, LocalIRVariable]:
         return self._function
 
     @property
-    def function_type(self):
+    def function_type(self) -> FunctionType:
         return self._function_type
 
     @property
@@ -62,14 +73,14 @@ class InternalDynamicCall(
         gas = ""
         args = [str(a) for a in self.arguments]
         if self.call_value:
-            value = "value:{}".format(self.call_value)
+            value = f"value:{self.call_value}"
         if self.call_gas:
-            gas = "gas:{}".format(self.call_gas)
+            gas = f"gas:{self.call_gas}"
         if not self.lvalue:
             lvalue = ""
         elif isinstance(self.lvalue.type, (list,)):
-            lvalue = "{}({}) = ".format(self.lvalue, ",".join(str(x) for x in self.lvalue.type))
+            lvalue = f"{self.lvalue}({','.join(str(x) for x in self.lvalue.type)}) = "
         else:
-            lvalue = "{}({}) = ".format(self.lvalue, self.lvalue.type)
+            lvalue = f"{self.lvalue}({self.lvalue.type}) = "
         txt = "{}INTERNAL_DYNAMIC_CALL {}({}) {} {}"
         return txt.format(lvalue, self.function.name, ",".join(args), value, gas)
