@@ -1,13 +1,14 @@
+from typing import Any, List
 from slither.slithir.operations.operation import Operation
 
 
 class OperationWithLValue(Operation):
-    '''
-        Operation with a lvalue
-    '''
+    """
+    Operation with a lvalue
+    """
 
-    def __init__(self):
-        super(OperationWithLValue, self).__init__()
+    def __init__(self) -> None:
+        super().__init__()
 
         self._lvalue = None
 
@@ -16,7 +17,7 @@ class OperationWithLValue(Operation):
         return self._lvalue
 
     @property
-    def used(self):
+    def used(self) -> List[Any]:
         return self.read + [self.lvalue]
 
     @lvalue.setter
