@@ -1,7 +1,9 @@
 import abc
+from typing import Any, List
 from slither.core.context.context import Context
 from slither.core.children.child_expression import ChildExpression
 from slither.core.children.child_node import ChildNode
+from slither.core.variables.variable import Variable
 from slither.utils.utils import unroll
 
 
@@ -25,7 +27,7 @@ class AbstractOperation(abc.ABC):
 
 class Operation(Context, ChildExpression, ChildNode, AbstractOperation):
     @property
-    def used(self):
+    def used(self) -> List[Variable]:
         """
         By default used is all the variables read
         """
@@ -33,5 +35,5 @@ class Operation(Context, ChildExpression, ChildNode, AbstractOperation):
 
     # if array inside the parameters
     @staticmethod
-    def _unroll(l):
+    def _unroll(l: List[Any]) -> List[Any]:
         return unroll(l)
