@@ -10,7 +10,7 @@ class ArgumentType(Enum):
 
 
 class Argument(Operation):
-    def __init__(self, argument):
+    def __init__(self, argument) -> None:
         super().__init__()
         self._argument = argument
         self._type = ArgumentType.CALL
@@ -32,15 +32,15 @@ class Argument(Operation):
     def read(self):
         return [self.argument]
 
-    def set_type(self, t):
+    def set_type(self, t: ArgumentType) -> None:
         assert isinstance(t, ArgumentType)
         self._type = t
 
-    def get_type(self):
+    def get_type(self) -> ArgumentType:
         return self._type
 
     def __str__(self):
         call_id = "none"
         if self.call_id:
-            call_id = "(id ({}))".format(self.call_id)
-        return "ARG_{} {} {}".format(self._type.name, str(self._argument), call_id)
+            call_id = f"(id ({self.call_id}))"
+        return f"ARG_{self._type.name} {str(self._argument)} {call_id}"
