@@ -1,12 +1,14 @@
+from typing import Set
 from slither.core.variables.local_variable import LocalVariable
 from slither.slithir.variables.temporary import TemporaryVariable
 from slither.slithir.variables.variable import SlithIRVariable
+from slither.slithir.variables.state_variable import StateIRVariable
 
 
 class LocalIRVariable(
     LocalVariable, SlithIRVariable
 ):  # pylint: disable=too-many-instance-attributes
-    def __init__(self, local_variable):
+    def __init__(self, local_variable: LocalVariable) -> None:
         assert isinstance(local_variable, LocalVariable)
 
         super().__init__()
@@ -30,7 +32,7 @@ class LocalIRVariable(
 
         # Additional field
         # points to state variables
-        self._refers_to = set()
+        self._refers_to: Set[StateIRVariable] = set()
 
         # keep un-ssa version
         if isinstance(local_variable, LocalIRVariable):
@@ -57,10 +59,10 @@ class LocalIRVariable(
         self._refers_to = variables
 
     @property
-    def non_ssa_version(self):
+    def non_ssa_version(self) -> LocalVariable:
         return self._non_ssa_version
 
-    def add_refers_to(self, variable):
+    def add_refers_to(self, variable: StateIRVariable) -> None:
         # It is a temporaryVariable if its the return of a new ..
         # ex: string[] memory dynargs = new string[](1);
         assert isinstance(variable, (SlithIRVariable, TemporaryVariable))
@@ -69,5 +71,5 @@ class LocalIRVariable(
     @property
     def ssa_name(self):
         if self.is_storage:
-            return "{}_{} (-> {})".format(self._name, self.index, [v.name for v in self.refers_to])
-        return "{}_{}".format(self._name, self.index)
+            return f"{self._name}_{self.index} (-> {[v.name for v in self.refers_to]})"
+        return f"{self._name}_{self.index}"
