@@ -1,11 +1,12 @@
 import logging
-from typing import List, Dict, Callable, TYPE_CHECKING, Union, Set
+import re
+from typing import Any, List, Dict, Callable, TYPE_CHECKING, Union, Set
 
 from slither.core.declarations import Modifier, Event, EnumContract, StructureContract, Function
 from slither.core.declarations.contract import Contract
 from slither.core.declarations.custom_error_contract import CustomErrorContract
 from slither.core.declarations.function_contract import FunctionContract
-from slither.core.solidity_types import ElementaryType, TypeAliasContract
+from slither.core.solidity_types import ElementaryType, TypeAliasContract, Type
 from slither.core.variables.state_variable import StateVariable
 from slither.solc_parsing.declarations.caller_context import CallerContextExpression
 from slither.solc_parsing.declarations.custom_error import CustomErrorSolc
@@ -21,14 +22,15 @@ LOGGER = logging.getLogger("ContractSolcParsing")
 
 if TYPE_CHECKING:
     from slither.solc_parsing.slither_compilation_unit_solc import SlitherCompilationUnitSolc
-    from slither.core.slither_core import SlitherCore
     from slither.core.compilation_unit import SlitherCompilationUnit
 
 # pylint: disable=too-many-instance-attributes,import-outside-toplevel,too-many-nested-blocks,too-many-public-methods
 
 
 class ContractSolc(CallerContextExpression):
-    def __init__(self, slither_parser: "SlitherCompilationUnitSolc", contract: Contract, data):
+    def __init__(
+        self, slither_parser: "SlitherCompilationUnitSolc", contract: Contract, data: Dict[str, Any]
+    ) -> None:
         # assert slitherSolc.solc_version.startswith('0.4')
 
         self._contract = contract
@@ -65,8 +67,10 @@ class ContractSolc(CallerContextExpression):
         # Export info
         if self.is_compact_ast:
             self._contract.name = self._data["name"]
+            self._handle_comment(self._data)
         else:
             self._contract.name = self._data["attributes"][self.get_key()]
+            self._handle_comment(self._data["attributes"])
 
         self._contract.id = self._data["id"]
 
@@ -83,7 +87,7 @@ class ContractSolc(CallerContextExpression):
     def is_analyzed(self) -> bool:
         return self._is_analyzed
 
-    def set_is_analyzed(self, is_analyzed: bool):
+    def set_is_analyzed(self, is_analyzed: bool) -> None:
         self._is_analyzed = is_analyzed
 
     @property
@@ -127,7 +131,7 @@ class ContractSolc(CallerContextExpression):
     def get_key(self) -> str:
         return self._slither_parser.get_key()
 
-    def get_children(self, key="nodes") -> str:
+    def get_children(self, key: str = "nodes") -> str:
         if self.is_compact_ast:
             return key
         return "children"
@@ -147,7 +151,7 @@ class ContractSolc(CallerContextExpression):
     ###################################################################################
     ###################################################################################
 
-    def _parse_contract_info(self):
+    def _parse_contract_info(self) -> None:
         if self.is_compact_ast:
             attributes = self._data
         else:
@@ -160,6 +164,7 @@ class ContractSolc(CallerContextExpression):
             elif attributes["contractKind"] == "library":
                 self._contract.is_library = True
             self._contract.contract_kind = attributes["contractKind"]
+            self._contract.is_fully_implemented = attributes["fullyImplemented"]
 
         self._linearized_base_contracts = attributes["linearizedBaseContracts"]
         # self._contract.fullyImplemented = attributes["fullyImplemented"]
@@ -175,7 +180,7 @@ class ContractSolc(CallerContextExpression):
                         "name"
                     ]
 
-    def _parse_base_contract_info(self):  # pylint: disable=too-many-branches
+    def _parse_base_contract_info(self) -> None:  # pylint: disable=too-many-branches
         # Parse base contracts (immediate, non-linearized)
         if self.is_compact_ast:
             # Parse base contracts + constructors in compact-ast
@@ -233,7 +238,7 @@ class ContractSolc(CallerContextExpression):
                     ):
                         self.baseConstructorContractsCalled.append(referencedDeclaration)
 
-    def _parse_contract_items(self):
+    def _parse_contract_items(self) -> None:
         # pylint: disable=too-many-branches
         if not self.get_children() in self._data:  # empty contract
             return
@@ -286,7 +291,7 @@ class ContractSolc(CallerContextExpression):
         self._contract.file_scope.user_defined_types[alias] = user_defined_type
         self._contract.file_scope.user_defined_types[alias_canonical] = user_defined_type
 
-    def _parse_struct(self, struct: Dict):
+    def _parse_struct(self, struct: Dict) -> None:
 
         st = StructureContract(self._contract.compilation_unit)
         st.set_contract(self._contract)
@@ -296,7 +301,7 @@ class ContractSolc(CallerContextExpression):
         self._contract.structures_as_dict[st.name] = st
         self._structures_parser.append(st_parser)
 
-    def parse_structs(self):
+    def parse_structs(self) -> None:
         for father in self._contract.inheritance_reverse:
             self._contract.structures_as_dict.update(father.structures_as_dict)
 
@@ -304,7 +309,7 @@ class ContractSolc(CallerContextExpression):
             self._parse_struct(struct)
         self._structuresNotParsed = None
 
-    def _parse_custom_error(self, custom_error: Dict):
+    def _parse_custom_error(self, custom_error: Dict) -> None:
         ce = CustomErrorContract(self.compilation_unit)
         ce.set_contract(self._contract)
         ce.set_offset(custom_error["src"], self.compilation_unit)
@@ -313,7 +318,7 @@ class ContractSolc(CallerContextExpression):
         self._contract.custom_errors_as_dict[ce.name] = ce
         self._custom_errors_parser.append(ce_parser)
 
-    def parse_custom_errors(self):
+    def parse_custom_errors(self) -> None:
         for father in self._contract.inheritance_reverse:
             self._contract.custom_errors_as_dict.update(father.custom_errors_as_dict)
 
@@ -321,9 +326,15 @@ class ContractSolc(CallerContextExpression):
             self._parse_custom_error(custom_error)
         self._customErrorParsed = None
 
-    def parse_state_variables(self):
+    def parse_state_variables(self) -> None:
         for father in self._contract.inheritance_reverse:
-            self._contract.variables_as_dict.update(father.variables_as_dict)
+            self._contract.variables_as_dict.update(
+                {
+                    name: v
+                    for name, v in father.variables_as_dict.items()
+                    if v.visibility != "private"
+                }
+            )
             self._contract.add_variables_ordered(
                 [
                     var
@@ -343,7 +354,7 @@ class ContractSolc(CallerContextExpression):
             self._contract.variables_as_dict[var.name] = var
             self._contract.add_variables_ordered([var])
 
-    def _parse_modifier(self, modifier_data: Dict):
+    def _parse_modifier(self, modifier_data: Dict) -> None:
         modif = Modifier(self._contract.compilation_unit)
         modif.set_offset(modifier_data["src"], self._contract.compilation_unit)
         modif.set_contract(self._contract)
@@ -356,12 +367,12 @@ class ContractSolc(CallerContextExpression):
 
         self._slither_parser.add_function_or_modifier_parser(modif_parser)
 
-    def parse_modifiers(self):
+    def parse_modifiers(self) -> None:
         for modifier in self._modifiersNotParsed:
             self._parse_modifier(modifier)
         self._modifiersNotParsed = None
 
-    def _parse_function(self, function_data: Dict):
+    def _parse_function(self, function_data: Dict) -> None:
         func = FunctionContract(self._contract.compilation_unit)
         func.set_offset(function_data["src"], self._contract.compilation_unit)
         func.set_contract(self._contract)
@@ -374,7 +385,7 @@ class ContractSolc(CallerContextExpression):
 
         self._slither_parser.add_function_or_modifier_parser(func_parser)
 
-    def parse_functions(self):
+    def parse_functions(self) -> None:
 
         for function in self._functionsNotParsed:
             self._parse_function(function)
@@ -388,27 +399,27 @@ class ContractSolc(CallerContextExpression):
     ###################################################################################
     ###################################################################################
 
-    def log_incorrect_parsing(self, error):
+    def log_incorrect_parsing(self, error: str) -> None:
         if self._contract.compilation_unit.core.disallow_partial:
             raise ParsingError(error)
         LOGGER.error(error)
-        self._contract.is_incorrectly_parsed = True
+        self._contract.is_incorrectly_constructed = True
 
-    def analyze_content_modifiers(self):
+    def analyze_content_modifiers(self) -> None:
         try:
             for modifier_parser in self._modifiers_parser:
                 modifier_parser.analyze_content()
         except (VariableNotFound, KeyError) as e:
             self.log_incorrect_parsing(f"Missing modifier {e}")
 
-    def analyze_content_functions(self):
+    def analyze_content_functions(self) -> None:
         try:
             for function_parser in self._functions_parser:
                 function_parser.analyze_content()
         except (VariableNotFound, KeyError, ParsingError) as e:
             self.log_incorrect_parsing(f"Missing function {e}")
 
-    def analyze_params_modifiers(self):
+    def analyze_params_modifiers(self) -> None:
         try:
             elements_no_params = self._modifiers_no_params
             getter = lambda c: c.modifiers_parser
@@ -428,7 +439,7 @@ class ContractSolc(CallerContextExpression):
             self.log_incorrect_parsing(f"Missing params {e}")
         self._modifiers_no_params = []
 
-    def analyze_params_functions(self):
+    def analyze_params_functions(self) -> None:
         try:
             elements_no_params = self._functions_no_params
             getter = lambda c: c.functions_parser
@@ -456,7 +467,7 @@ class ContractSolc(CallerContextExpression):
         explored_reference_id: Set[str],
         parser: List[FunctionSolc],
         all_elements: Dict[str, Function],
-    ):
+    ) -> None:
         elem = Cls(self._contract.compilation_unit)
         elem.set_contract(self._contract)
         underlying_function = element_parser.underlying_function
@@ -557,7 +568,7 @@ class ContractSolc(CallerContextExpression):
             self.log_incorrect_parsing(f"Missing params {e}")
         return all_elements
 
-    def analyze_constant_state_variables(self):
+    def analyze_constant_state_variables(self) -> None:
         for var_parser in self._variables_parser:
             if var_parser.underlying_variable.is_constant:
                 # cant parse constant expression based on function calls
@@ -566,7 +577,7 @@ class ContractSolc(CallerContextExpression):
                 except (VariableNotFound, KeyError) as e:
                     LOGGER.error(e)
 
-    def analyze_state_variables(self):
+    def analyze_state_variables(self) -> None:
         try:
             for var_parser in self._variables_parser:
                 var_parser.analyze(self)
@@ -574,21 +585,26 @@ class ContractSolc(CallerContextExpression):
         except (VariableNotFound, KeyError) as e:
             self.log_incorrect_parsing(f"Missing state variable {e}")
 
-    def analyze_using_for(self):
+    def analyze_using_for(self) -> None:  # pylint: disable=too-many-branches
         try:
             for father in self._contract.inheritance:
                 self._contract.using_for.update(father.using_for)
-
             if self.is_compact_ast:
                 for using_for in self._usingForNotParsed:
-                    lib_name = parse_type(using_for["libraryName"], self)
                     if "typeName" in using_for and using_for["typeName"]:
                         type_name = parse_type(using_for["typeName"], self)
                     else:
                         type_name = "*"
                     if type_name not in self._contract.using_for:
                         self._contract.using_for[type_name] = []
-                    self._contract.using_for[type_name].append(lib_name)
+
+                    if "libraryName" in using_for:
+                        self._contract.using_for[type_name].append(
+                            parse_type(using_for["libraryName"], self)
+                        )
+                    else:
+                        # We have a list of functions. A function can be topLevel or a library function
+                        self._analyze_function_list(using_for["functionList"], type_name)
             else:
                 for using_for in self._usingForNotParsed:
                     children = using_for[self.get_children()]
@@ -606,7 +622,60 @@ class ContractSolc(CallerContextExpression):
         except (VariableNotFound, KeyError) as e:
             self.log_incorrect_parsing(f"Missing using for {e}")
 
-    def analyze_enums(self):
+    def _analyze_function_list(self, function_list: List, type_name: Type) -> None:
+        for f in function_list:
+            full_name_split = f["function"]["name"].split(".")
+            if len(full_name_split) == 1:
+                # Top level function
+                function_name = full_name_split[0]
+                self._analyze_top_level_function(function_name, type_name)
+            elif len(full_name_split) == 2:
+                # It can be a top level function behind an aliased import
+                # or a library function
+                first_part = full_name_split[0]
+                function_name = full_name_split[1]
+                self._check_aliased_import(first_part, function_name, type_name)
+            else:
+                # MyImport.MyLib.a we don't care of the alias
+                library_name = full_name_split[1]
+                function_name = full_name_split[2]
+                self._analyze_library_function(library_name, function_name, type_name)
+
+    def _check_aliased_import(self, first_part: str, function_name: str, type_name: Type) -> None:
+        # We check if the first part appear as alias for an import
+        # if it is then function_name must be a top level function
+        # otherwise it's a library function
+        for i in self._contract.file_scope.imports:
+            if i.alias == first_part:
+                self._analyze_top_level_function(function_name, type_name)
+                return
+        self._analyze_library_function(first_part, function_name, type_name)
+
+    def _analyze_top_level_function(self, function_name: str, type_name: Type) -> None:
+        for tl_function in self.compilation_unit.functions_top_level:
+            if tl_function.name == function_name:
+                self._contract.using_for[type_name].append(tl_function)
+
+    def _analyze_library_function(
+        self, library_name: str, function_name: str, type_name: Type
+    ) -> None:
+        # Get the library function
+        found = False
+        for c in self.compilation_unit.contracts:
+            if found:
+                break
+            if c.name == library_name:
+                for f in c.functions:
+                    if f.name == function_name:
+                        self._contract.using_for[type_name].append(f)
+                        found = True
+                        break
+        if not found:
+            self.log_incorrect_parsing(
+                f"Contract level using for: Library {library_name} - function {function_name} not found"
+            )
+
+    def analyze_enums(self) -> None:
         try:
             for father in self._contract.inheritance:
                 self._contract.enums_as_dict.update(father.enums_as_dict)
@@ -619,7 +688,19 @@ class ContractSolc(CallerContextExpression):
         except (VariableNotFound, KeyError) as e:
             self.log_incorrect_parsing(f"Missing enum {e}")
 
-    def _analyze_enum(self, enum):
+    def _analyze_enum(
+        self,
+        enum: Dict[
+            str,
+            Union[
+                str,
+                int,
+                List[Dict[str, Union[int, str]]],
+                Dict[str, str],
+                List[Dict[str, Union[Dict[str, str], int, str]]],
+            ],
+        ],
+    ) -> None:
         # Enum can be parsed in one pass
         if self.is_compact_ast:
             name = enum["name"]
@@ -643,21 +724,21 @@ class ContractSolc(CallerContextExpression):
         new_enum.set_offset(enum["src"], self._contract.compilation_unit)
         self._contract.enums_as_dict[canonicalName] = new_enum
 
-    def _analyze_struct(self, struct: StructureContractSolc):  # pylint: disable=no-self-use
+    def _analyze_struct(self, struct: StructureContractSolc) -> None:  # pylint: disable=no-self-use
         struct.analyze()
 
-    def analyze_structs(self):
+    def analyze_structs(self) -> None:
         try:
             for struct in self._structures_parser:
                 self._analyze_struct(struct)
         except (VariableNotFound, KeyError) as e:
             self.log_incorrect_parsing(f"Missing struct {e}")
 
-    def analyze_custom_errors(self):
+    def analyze_custom_errors(self) -> None:
         for custom_error in self._custom_errors_parser:
             custom_error.analyze_params()
 
-    def analyze_events(self):
+    def analyze_events(self) -> None:
         try:
             for father in self._contract.inheritance_reverse:
                 self._contract.events_as_dict.update(father.events_as_dict)
@@ -699,6 +780,47 @@ class ContractSolc(CallerContextExpression):
         self._usingForNotParsed = []
         self._customErrorParsed = []
 
+    def _handle_comment(self, attributes: Dict) -> None:
+        """
+        Save the contract comment in self.comments
+        And handle custom slither comments
+
+        Args:
+            attributes:
+
+        Returns:
+
+        """
+        # Old solc versions store the comment in attributes["documentation"]
+        # More recent ones store it in attributes["documentation"]["text"]
+        if (
+            "documentation" in attributes
+            and attributes["documentation"] is not None
+            and (
+                "text" in attributes["documentation"]
+                or isinstance(attributes["documentation"], str)
+            )
+        ):
+            text = (
+                attributes["documentation"]
+                if isinstance(attributes["documentation"], str)
+                else attributes["documentation"]["text"]
+            )
+            self._contract.comments = text
+
+            # Look for custom comments
+            candidates = text.replace("\n", ",").split(",")
+
+            for candidate in candidates:
+                if "@custom:security isDelegatecallProxy" in candidate:
+                    self._contract.is_upgradeable_proxy = True
+                if "@custom:security isUpgradeable" in candidate:
+                    self._contract.is_upgradeable = True
+
+                version_name = re.search(r"@custom:version name=([\w-]+)", candidate)
+                if version_name:
+                    self._contract.upgradeable_version = version_name.group(1)
+
     # endregion
     ###################################################################################
     ###################################################################################
