@@ -14,14 +14,17 @@ from slither.core.declarations.function_top_level import FunctionTopLevel
 from slither.core.declarations.import_directive import Import
 from slither.core.declarations.pragma_directive import Pragma
 from slither.core.declarations.structure_top_level import StructureTopLevel
+from slither.core.declarations.using_for_top_level import UsingForTopLevel
 from slither.core.scope.scope import FileScope
 from slither.core.solidity_types import ElementaryType, TypeAliasTopLevel
 from slither.core.variables.top_level_variable import TopLevelVariable
 from slither.exceptions import SlitherException
+from slither.solc_parsing.declarations.caller_context import CallerContextExpression
 from slither.solc_parsing.declarations.contract import ContractSolc
 from slither.solc_parsing.declarations.custom_error import CustomErrorSolc
 from slither.solc_parsing.declarations.function import FunctionSolc
 from slither.solc_parsing.declarations.structure_top_level import StructureTopLevelSolc
+from slither.solc_parsing.declarations.using_for_top_level import UsingForTopLevelSolc
 from slither.solc_parsing.exceptions import VariableNotFound
 from slither.solc_parsing.variables.top_level_variable import TopLevelVariableSolc
 
@@ -45,21 +48,27 @@ def _handle_import_aliases(
 
     """
     for symbol_alias in symbol_aliases:
-        if (
-            "foreign" in symbol_alias
-            and "name" in symbol_alias["foreign"]
-            and "local" in symbol_alias
-        ):
-            original_name = symbol_alias["foreign"]["name"]
-            local_name = symbol_alias["local"]
-            import_directive.renaming[local_name] = original_name
-            # Assuming that two imports cannot collide in renaming
-            scope.renaming[local_name] = original_name
+        if "foreign" in symbol_alias and "local" in symbol_alias:
+            if isinstance(symbol_alias["foreign"], dict) and "name" in symbol_alias["foreign"]:
+
+                original_name = symbol_alias["foreign"]["name"]
+                local_name = symbol_alias["local"]
+                import_directive.renaming[local_name] = original_name
+                # Assuming that two imports cannot collide in renaming
+                scope.renaming[local_name] = original_name
+
+            # This path should only be hit for the malformed AST of solc 0.5.12 where
+            # the foreign identifier cannot be found but is required to resolve the alias.
+            # see https://github.com/crytic/slither/issues/1319
+            elif symbol_alias["local"]:
+                raise SlitherException(
+                    "Cannot resolve local alias for import directive due to malformed AST. Please upgrade to solc 0.6.0 or higher."
+                )
 
 
-class SlitherCompilationUnitSolc:
+class SlitherCompilationUnitSolc(CallerContextExpression):
     # pylint: disable=no-self-use,too-many-instance-attributes
-    def __init__(self, compilation_unit: SlitherCompilationUnit):
+    def __init__(self, compilation_unit: SlitherCompilationUnit) -> None:
         super().__init__()
 
         self._contracts_by_id: Dict[int, ContractSolc] = {}
@@ -71,6 +80,7 @@ class SlitherCompilationUnitSolc:
         self._custom_error_parser: List[CustomErrorSolc] = []
         self._variables_top_level_parser: List[TopLevelVariableSolc] = []
         self._functions_top_level_parser: List[FunctionSolc] = []
+        self._using_for_top_level_parser: List[UsingForTopLevelSolc] = []
 
         self._is_compact_ast = False
         # self._core: SlitherCore = core
@@ -88,13 +98,17 @@ class SlitherCompilationUnitSolc:
     def all_functions_and_modifiers_parser(self) -> List[FunctionSolc]:
         return self._all_functions_and_modifier_parser
 
-    def add_function_or_modifier_parser(self, f: FunctionSolc):
+    def add_function_or_modifier_parser(self, f: FunctionSolc) -> None:
         self._all_functions_and_modifier_parser.append(f)
 
     @property
     def underlying_contract_to_parser(self) -> Dict[Contract, ContractSolc]:
         return self._underlying_contract_to_parser
 
+    @property
+    def slither_parser(self) -> "SlitherCompilationUnitSolc":
+        return self
+
     ###################################################################################
     ###################################################################################
     # region AST
@@ -149,7 +163,7 @@ class SlitherCompilationUnitSolc:
                 return True
             return False
 
-    def _parse_enum(self, top_level_data: Dict, filename: str):
+    def _parse_enum(self, top_level_data: Dict, filename: str) -> None:
         if self.is_compact_ast:
             name = top_level_data["name"]
             canonicalName = top_level_data["canonicalName"]
@@ -178,9 +192,8 @@ class SlitherCompilationUnitSolc:
         enum.set_offset(top_level_data["src"], self._compilation_unit)
         self._compilation_unit.enums_top_level.append(enum)
 
-    def parse_top_level_from_loaded_json(
-        self, data_loaded: Dict, filename: str
-    ):  # pylint: disable=too-many-branches,too-many-statements,too-many-locals
+    # pylint: disable=too-many-branches,too-many-statements,too-many-locals
+    def parse_top_level_from_loaded_json(self, data_loaded: Dict, filename: str) -> None:
         if "nodeType" in data_loaded:
             self._is_compact_ast = True
 
@@ -221,6 +234,17 @@ class SlitherCompilationUnitSolc:
                     scope.pragmas.add(pragma)
                 pragma.set_offset(top_level_data["src"], self._compilation_unit)
                 self._compilation_unit.pragma_directives.append(pragma)
+
+            elif top_level_data[self.get_key()] == "UsingForDirective":
+                scope = self.compilation_unit.get_scope(filename)
+                usingFor = UsingForTopLevel(scope)
+                usingFor_parser = UsingForTopLevelSolc(usingFor, top_level_data, self)
+                usingFor.set_offset(top_level_data["src"], self._compilation_unit)
+                scope.using_for_directives.add(usingFor)
+
+                self._compilation_unit.using_for_top_level.append(usingFor)
+                self._using_for_top_level_parser.append(usingFor_parser)
+
             elif top_level_data[self.get_key()] == "ImportDirective":
                 if self.is_compact_ast:
                     import_directive = Import(
@@ -311,12 +335,13 @@ class SlitherCompilationUnitSolc:
 
                 user_defined_type = TypeAliasTopLevel(original_type, alias, scope)
                 user_defined_type.set_offset(top_level_data["src"], self._compilation_unit)
+                self._compilation_unit.user_defined_value_types[alias] = user_defined_type
                 scope.user_defined_types[alias] = user_defined_type
 
             else:
                 raise SlitherException(f"Top level {top_level_data[self.get_key()]} not supported")
 
-    def _parse_source_unit(self, data: Dict, filename: str):
+    def _parse_source_unit(self, data: Dict, filename: str) -> None:
         if data[self.get_key()] != "SourceUnit":
             return  # handle solc prior 0.3.6
 
@@ -366,7 +391,7 @@ class SlitherCompilationUnitSolc:
     def analyzed(self) -> bool:
         return self._analyzed
 
-    def parse_contracts(self):  # pylint: disable=too-many-statements,too-many-branches
+    def parse_contracts(self) -> None:  # pylint: disable=too-many-statements,too-many-branches
         if not self._underlying_contract_to_parser:
             logger.info(
                 f"No contract were found in {self._compilation_unit.core.filename}, check the correct compilation"
@@ -491,10 +516,13 @@ Please rename it, this name is reserved for Slither's internals"""
 
         # Then we analyse state variables, functions and modifiers
         self._analyze_third_part(contracts_to_be_analyzed, libraries)
+        [c.set_is_analyzed(False) for c in self._underlying_contract_to_parser.values()]
+
+        self._analyze_using_for(contracts_to_be_analyzed, libraries)
 
         self._parsed = True
 
-    def analyze_contracts(self):  # pylint: disable=too-many-statements,too-many-branches
+    def analyze_contracts(self) -> None:  # pylint: disable=too-many-statements,too-many-branches
         if not self._parsed:
             raise SlitherException("Parse the contract before running analyses")
         self._convert_to_slithir()
@@ -503,7 +531,7 @@ Please rename it, this name is reserved for Slither's internals"""
         self._compilation_unit.compute_storage_layout()
         self._analyzed = True
 
-    def _analyze_all_enums(self, contracts_to_be_analyzed: List[ContractSolc]):
+    def _analyze_all_enums(self, contracts_to_be_analyzed: List[ContractSolc]) -> None:
         while contracts_to_be_analyzed:
             contract = contracts_to_be_analyzed[0]
 
@@ -522,7 +550,7 @@ Please rename it, this name is reserved for Slither's internals"""
         self,
         contracts_to_be_analyzed: List[ContractSolc],
         libraries: List[ContractSolc],
-    ):
+    ) -> None:
         for lib in libraries:
             self._parse_struct_var_modifiers_functions(lib)
 
@@ -549,7 +577,7 @@ Please rename it, this name is reserved for Slither's internals"""
         self,
         contracts_to_be_analyzed: List[ContractSolc],
         libraries: List[ContractSolc],
-    ):
+    ) -> None:
         for lib in libraries:
             self._analyze_struct_events(lib)
 
@@ -579,7 +607,7 @@ Please rename it, this name is reserved for Slither's internals"""
         self,
         contracts_to_be_analyzed: List[ContractSolc],
         libraries: List[ContractSolc],
-    ):
+    ) -> None:
         for lib in libraries:
             self._analyze_variables_modifiers_functions(lib)
 
@@ -602,12 +630,35 @@ Please rename it, this name is reserved for Slither's internals"""
             else:
                 contracts_to_be_analyzed += [contract]
 
-    def _analyze_enums(self, contract: ContractSolc):
+    def _analyze_using_for(
+        self, contracts_to_be_analyzed: List[ContractSolc], libraries: List[ContractSolc]
+    ) -> None:
+        self._analyze_top_level_using_for()
+
+        for lib in libraries:
+            lib.analyze_using_for()
+
+        while contracts_to_be_analyzed:
+            contract = contracts_to_be_analyzed[0]
+
+            contracts_to_be_analyzed = contracts_to_be_analyzed[1:]
+            all_father_analyzed = all(
+                self._underlying_contract_to_parser[father].is_analyzed
+                for father in contract.underlying_contract.inheritance
+            )
+
+            if not contract.underlying_contract.inheritance or all_father_analyzed:
+                contract.analyze_using_for()
+                contract.set_is_analyzed(True)
+            else:
+                contracts_to_be_analyzed += [contract]
+
+    def _analyze_enums(self, contract: ContractSolc) -> None:
         # Enum must be analyzed first
         contract.analyze_enums()
         contract.set_is_analyzed(True)
 
-    def _parse_struct_var_modifiers_functions(self, contract: ContractSolc):
+    def _parse_struct_var_modifiers_functions(self, contract: ContractSolc) -> None:
         contract.parse_structs()  # struct can refer another struct
         contract.parse_state_variables()
         contract.parse_modifiers()
@@ -615,7 +666,7 @@ Please rename it, this name is reserved for Slither's internals"""
         contract.parse_custom_errors()
         contract.set_is_analyzed(True)
 
-    def _analyze_struct_events(self, contract: ContractSolc):
+    def _analyze_struct_events(self, contract: ContractSolc) -> None:
 
         contract.analyze_constant_state_variables()
 
@@ -624,42 +675,45 @@ Please rename it, this name is reserved for Slither's internals"""
         # Event can refer to struct
         contract.analyze_events()
 
-        contract.analyze_using_for()
         contract.analyze_custom_errors()
 
         contract.set_is_analyzed(True)
 
-    def _analyze_top_level_structures(self):
+    def _analyze_top_level_structures(self) -> None:
         try:
             for struct in self._structures_top_level_parser:
                 struct.analyze()
         except (VariableNotFound, KeyError) as e:
             raise SlitherException(f"Missing struct {e} during top level structure analyze") from e
 
-    def _analyze_top_level_variables(self):
+    def _analyze_top_level_variables(self) -> None:
         try:
             for var in self._variables_top_level_parser:
                 var.analyze(var)
         except (VariableNotFound, KeyError) as e:
             raise SlitherException(f"Missing {e} during variable analyze") from e
 
-    def _analyze_params_top_level_function(self):
+    def _analyze_params_top_level_function(self) -> None:
         for func_parser in self._functions_top_level_parser:
             func_parser.analyze_params()
             self._compilation_unit.add_function(func_parser.underlying_function)
 
-    def _analyze_params_custom_error(self):
+    def _analyze_top_level_using_for(self) -> None:
+        for using_for in self._using_for_top_level_parser:
+            using_for.analyze()
+
+    def _analyze_params_custom_error(self) -> None:
         for custom_error_parser in self._custom_error_parser:
             custom_error_parser.analyze_params()
 
-    def _analyze_content_top_level_function(self):
+    def _analyze_content_top_level_function(self) -> None:
         try:
             for func_parser in self._functions_top_level_parser:
                 func_parser.analyze_content()
         except (VariableNotFound, KeyError) as e:
             raise SlitherException(f"Missing {e} during top level function analyze") from e
 
-    def _analyze_variables_modifiers_functions(self, contract: ContractSolc):
+    def _analyze_variables_modifiers_functions(self, contract: ContractSolc) -> None:
         # State variables, modifiers and functions can refer to anything
 
         contract.analyze_params_modifiers()
@@ -675,7 +729,7 @@ Please rename it, this name is reserved for Slither's internals"""
 
         contract.set_is_analyzed(True)
 
-    def _convert_to_slithir(self):
+    def _convert_to_slithir(self) -> None:
 
         for contract in self._compilation_unit.contracts:
             contract.add_constructor_variables()
@@ -683,12 +737,13 @@ Please rename it, this name is reserved for Slither's internals"""
             for func in contract.functions + contract.modifiers:
                 try:
                     func.generate_slithir_and_analyze()
+
                 except AttributeError as e:
                     # This can happens for example if there is a call to an interface
                     # And the interface is redefined due to contract's name reuse
                     # But the available version misses some functions
                     self._underlying_contract_to_parser[contract].log_incorrect_parsing(
-                        f"Impossible to generate IR for {contract.name}.{func.name}:\n {e}"
+                        f"Impossible to generate IR for {contract.name}.{func.name} ({func.source_mapping}):\n {e}"
                     )
 
             contract.convert_expression_to_slithir_ssa()
