@@ -1,17 +1,21 @@
+from typing import Dict
+
 from slither.core.expressions import Literal
-from slither.tools.mutator.mutators.abstract_mutator import AbstractMutator, FaultNature, FaulClass
+from slither.core.variables.variable import Variable
+from slither.tools.mutator.mutators.abstract_mutator import AbstractMutator, FaultNature, FaultClass
 from slither.tools.mutator.utils.generic_patching import remove_assignement
 
 
 class MVIV(AbstractMutator):  # pylint: disable=too-few-public-methods
     NAME = "MVIV"
     HELP = "variable initialization using a value"
-    FAULTCLASS = FaulClass.Assignement
+    FAULTCLASS = FaultClass.Assignement
     FAULTNATURE = FaultNature.Missing
 
-    def _mutate(self):
+    def _mutate(self) -> Dict:
 
-        result = dict()
+        result: Dict = {}
+        variable: Variable
 
         for contract in self.slither.contracts:
 
@@ -25,7 +29,7 @@ class MVIV(AbstractMutator):  # pylint: disable=too-few-public-methods
                     if isinstance(variable.expression, Literal):
                         remove_assignement(variable, contract, result)
 
-            for function in contract.functions_declared + contract.modifiers_declared:
+            for function in contract.functions_declared + list(contract.modifiers_declared):
                 for variable in function.local_variables:
                     if variable.initialized and isinstance(variable.expression, Literal):
                         remove_assignement(variable, contract, result)
