@@ -11,10 +11,14 @@ class WereConstant(AbstractCheck):
     HELP = "Variables that should be constant"
     WIKI = "https://github.com/crytic/slither/wiki/Upgradeability-Checks#variables-that-should-be-constant"
     WIKI_TITLE = "Variables that should be constant"
+
+    # region wiki_description
     WIKI_DESCRIPTION = """
 Detect state variables that should be `constant̀`.
 """
+    # endregion wiki_description
 
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract Contract{
@@ -32,10 +36,13 @@ contract ContractV2{
 Because `variable2` is not anymore a `constant`, the storage location of `variable3` will be different.
 As a result, `ContractV2` will have a corrupted storage layout.
 """
+    # endregion wiki_exploit_scenario
 
+    # region wiki_recommendation
     WIKI_RECOMMENDATION = """
 Do not remove `constant` from a state variables during an update.
 """
+    # endregion wiki_recommendation
 
     REQUIRE_CONTRACT = True
     REQUIRE_CONTRACT_V2 = True
@@ -48,8 +55,7 @@ Do not remove `constant` from a state variables during an update.
         state_variables_v2 = contract_v2.state_variables
 
         v2_additional_variables = len(state_variables_v2) - len(state_variables_v1)
-        if v2_additional_variables < 0:
-            v2_additional_variables = 0
+        v2_additional_variables = max(v2_additional_variables, 0)
 
         # We keep two index, because we need to have them out of sync if v2
         # has additional non constant variables
@@ -93,10 +99,13 @@ class BecameConstant(AbstractCheck):
     WIKI = "https://github.com/crytic/slither/wiki/Upgradeability-Checks#variables-that-should-not-be-constant"
     WIKI_TITLE = "Variables that should not be constant"
 
+    # region wiki_description
     WIKI_DESCRIPTION = """
 Detect state variables that should not be `constant̀`.
 """
+    # endregion wiki_description
 
+    # region wiki_exploit_scenario
     WIKI_EXPLOIT_SCENARIO = """
 ```solidity
 contract Contract{
@@ -114,10 +123,13 @@ contract ContractV2{
 Because `variable2` is now a `constant`, the storage location of `variable3` will be different.
 As a result, `ContractV2` will have a corrupted storage layout.
 """
+    # endregion wiki_exploit_scenario
 
+    # region wiki_recommendation
     WIKI_RECOMMENDATION = """
 Do not make an existing state variable `constant`.
 """
+    # endregion wiki_recommendation
 
     REQUIRE_CONTRACT = True
     REQUIRE_CONTRACT_V2 = True
@@ -130,8 +142,7 @@ Do not make an existing state variable `constant`.
         state_variables_v2 = contract_v2.state_variables
 
         v2_additional_variables = len(state_variables_v2) - len(state_variables_v1)
-        if v2_additional_variables < 0:
-            v2_additional_variables = 0
+        v2_additional_variables = max(v2_additional_variables, 0)
 
         # We keep two index, because we need to have them out of sync if v2
         # has additional non constant variables
