@@ -39,8 +39,8 @@ Using initialize functions to write initial values in state variables.
 
     def _check(self):
         results = []
-        for s in self.contract.state_variables:
-            if s.initialized and not s.is_constant:
+        for s in self.contract.state_variables_ordered:
+            if s.initialized and not (s.is_constant or s.is_immutable):
                 info = [s, " is a state variable with an initial value.\n"]
                 json = self.generate_result(info)
                 results.append(json)
