@@ -1,11 +1,12 @@
 import hashlib
-import os
 import json
 import logging
+import os
 import zipfile
 from collections import OrderedDict
-from typing import Optional, Dict, List, Union, Any, TYPE_CHECKING
+from typing import Tuple, Optional, Dict, List, Union, Any, TYPE_CHECKING, Type
 from zipfile import ZipFile
+
 from pkg_resources import require
 
 from slither.core.cfg.node import Node
@@ -22,7 +23,6 @@ if TYPE_CHECKING:
 
 logger = logging.getLogger("Slither")
 
-
 ###################################################################################
 ###################################################################################
 # region Output
@@ -130,7 +130,7 @@ def _output_result_to_sarif(
 
 
 def output_to_sarif(
-    filename: Optional[str], results: Dict, detectors_classes: List["AbstractDetector"]
+    filename: Optional[str], results: Dict, detectors_classes: List[Type["AbstractDetector"]]
 ) -> None:
     """
 
@@ -160,7 +160,7 @@ def output_to_sarif(
         ],
     }
 
-    for detector in results["detectors"]:
+    for detector in results.get("detectors", []):
         _output_result_to_sarif(detector, detectors_classes, sarif)
 
     if filename == "-":
@@ -219,7 +219,7 @@ def output_to_zip(filename: str, error: Optional[str], results: Dict, zip_type:
 ###################################################################################
 
 
-def _convert_to_description(d):
+def _convert_to_description(d: str) -> str:
     if isinstance(d, str):
         return d
 
@@ -228,19 +228,19 @@ def _convert_to_description(d):
 
     if isinstance(d, Node):
         if d.expression:
-            return f"{d.expression} ({d.source_mapping_str})"
-        return f"{str(d)} ({d.source_mapping_str})"
+            return f"{d.expression} ({d.source_mapping})"
+        return f"{str(d)} ({d.source_mapping})"
 
     if hasattr(d, "canonical_name"):
-        return f"{d.canonical_name} ({d.source_mapping_str})"
+        return f"{d.canonical_name} ({d.source_mapping})"
 
     if hasattr(d, "name"):
-        return f"{d.name} ({d.source_mapping_str})"
+        return f"{d.name} ({d.source_mapping})"
 
     raise SlitherError(f"{type(d)} cannot be converted (no name, or canonical_name")
 
 
-def _convert_to_markdown(d, markdown_root):
+def _convert_to_markdown(d: str, markdown_root: str) -> str:
     if isinstance(d, str):
         return d
 
@@ -249,19 +249,19 @@ def _convert_to_markdown(d, markdown_root):
 
     if isinstance(d, Node):
         if d.expression:
-            return f"[{d.expression}]({d.source_mapping_to_markdown(markdown_root)})"
-        return f"[{str(d)}]({d.source_mapping_to_markdown(markdown_root)})"
+            return f"[{d.expression}]({d.source_mapping.to_markdown(markdown_root)})"
+        return f"[{str(d)}]({d.source_mapping.to_markdown(markdown_root)})"
 
     if hasattr(d, "canonical_name"):
-        return f"[{d.canonical_name}]({d.source_mapping_to_markdown(markdown_root)})"
+        return f"[{d.canonical_name}]({d.source_mapping.to_markdown(markdown_root)})"
 
     if hasattr(d, "name"):
-        return f"[{d.name}]({d.source_mapping_to_markdown(markdown_root)})"
+        return f"[{d.name}]({d.source_mapping.to_markdown(markdown_root)})"
 
     raise SlitherError(f"{type(d)} cannot be converted (no name, or canonical_name")
 
 
-def _convert_to_id(d):
+def _convert_to_id(d: str) -> str:
     """
     Id keeps the source mapping of the node, otherwise we risk to consider two different node as the same
     :param d:
@@ -275,11 +275,11 @@ def _convert_to_id(d):
 
     if isinstance(d, Node):
         if d.expression:
-            return f"{d.expression} ({d.source_mapping_str})"
-        return f"{str(d)} ({d.source_mapping_str})"
+            return f"{d.expression} ({d.source_mapping})"
+        return f"{str(d)} ({d.source_mapping})"
 
     if isinstance(d, Pragma):
-        return f"{d} ({d.source_mapping_str})"
+        return f"{d} ({d.source_mapping})"
 
     if hasattr(d, "canonical_name"):
         return f"{d.canonical_name}"
@@ -299,8 +299,35 @@ def _convert_to_id(d):
 
 
 def _create_base_element(
-    custom_type, name, source_mapping, type_specific_fields=None, additional_fields=None
-):
+    custom_type: str,
+    name: str,
+    source_mapping: Dict,
+    type_specific_fields: Optional[
+        Dict[
+            str,
+            Union[
+                Dict[
+                    str,
+                    Union[
+                        str,
+                        Dict[str, Union[int, str, bool, List[int]]],
+                        Dict[
+                            str,
+                            Union[
+                                Dict[str, Union[str, Dict[str, Union[int, str, bool, List[int]]]]],
+                                str,
+                            ],
+                        ],
+                    ],
+                ],
+                Dict[str, Union[str, Dict[str, Union[int, str, bool, List[int]]]]],
+                str,
+                List[str],
+            ],
+        ]
+    ] = None,
+    additional_fields: Optional[Dict[str, str]] = None,
+) -> Dict[str, Any]:
     if additional_fields is None:
         additional_fields = {}
     if type_specific_fields is None:
@@ -313,7 +340,16 @@ def _create_base_element(
     return element
 
 
-def _create_parent_element(element):
+def _create_parent_element(
+    element: SourceMapping,
+) -> Dict[
+    str,
+    Union[
+        str,
+        Dict[str, Union[int, str, bool, List[int]]],
+        Dict[str, Union[Dict[str, Union[str, Dict[str, Union[int, str, bool, List[int]]]]], str]],
+    ],
+]:
     # pylint: disable=import-outside-toplevel
     from slither.core.children.child_contract import ChildContract
     from slither.core.children.child_function import ChildFunction
@@ -346,9 +382,9 @@ class Output:
         self,
         info_: Union[str, List[Union[str, SupportedOutput]]],
         additional_fields: Optional[Dict] = None,
-        markdown_root="",
-        standard_format=True,
-    ):
+        markdown_root: str = "",
+        standard_format: bool = True,
+    ) -> None:
         if additional_fields is None:
             additional_fields = {}
 
@@ -359,7 +395,7 @@ class Output:
         else:
             info = info_
 
-        self._data: Dict[str, Any] = OrderedDict()
+        self._data = OrderedDict()
         self._data["elements"] = []
         self._data["description"] = "".join(_convert_to_description(d) for d in info)
         self._data["markdown"] = "".join(_convert_to_markdown(d, markdown_root) for d in info)
@@ -378,9 +414,9 @@ class Output:
         if additional_fields:
             self._data["additional_fields"] = additional_fields
 
-    def add(self, add: SupportedOutput, additional_fields: Optional[Dict] = None):
+    def add(self, add: SupportedOutput, additional_fields: Optional[Dict] = None) -> None:
         if not self._data["first_markdown_element"]:
-            self._data["first_markdown_element"] = add.source_mapping_to_markdown(
+            self._data["first_markdown_element"] = add.source_mapping.to_markdown(
                 self._markdown_root
             )
         if isinstance(add, Variable):
@@ -417,14 +453,14 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_variable(self, variable: Variable, additional_fields: Optional[Dict] = None):
+    def add_variable(self, variable: Variable, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {"parent": _create_parent_element(variable)}
         element = _create_base_element(
             "variable",
             variable.name,
-            variable.source_mapping,
+            variable.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -441,11 +477,11 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_contract(self, contract: Contract, additional_fields: Optional[Dict] = None):
+    def add_contract(self, contract: Contract, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         element = _create_base_element(
-            "contract", contract.name, contract.source_mapping, {}, additional_fields
+            "contract", contract.name, contract.source_mapping.to_json(), {}, additional_fields
         )
         self._data["elements"].append(element)
 
@@ -456,7 +492,7 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_function(self, function: Function, additional_fields: Optional[Dict] = None):
+    def add_function(self, function: Function, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
@@ -466,7 +502,7 @@ class Output:
         element = _create_base_element(
             "function",
             function.name,
-            function.source_mapping,
+            function.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -485,14 +521,14 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_enum(self, enum: Enum, additional_fields: Optional[Dict] = None):
+    def add_enum(self, enum: Enum, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {"parent": _create_parent_element(enum)}
         element = _create_base_element(
             "enum",
             enum.name,
-            enum.source_mapping,
+            enum.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -505,14 +541,14 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_struct(self, struct: Structure, additional_fields: Optional[Dict] = None):
+    def add_struct(self, struct: Structure, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {"parent": _create_parent_element(struct)}
         element = _create_base_element(
             "struct",
             struct.name,
-            struct.source_mapping,
+            struct.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -525,7 +561,7 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_event(self, event: Event, additional_fields: Optional[Dict] = None):
+    def add_event(self, event: Event, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
@@ -535,7 +571,7 @@ class Output:
         element = _create_base_element(
             "event",
             event.name,
-            event.source_mapping,
+            event.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -549,7 +585,7 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_node(self, node: Node, additional_fields: Optional[Dict] = None):
+    def add_node(self, node: Node, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {
@@ -559,7 +595,7 @@ class Output:
         element = _create_base_element(
             "node",
             node_name,
-            node.source_mapping,
+            node.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -576,14 +612,14 @@ class Output:
     ###################################################################################
     ###################################################################################
 
-    def add_pragma(self, pragma: Pragma, additional_fields: Optional[Dict] = None):
+    def add_pragma(self, pragma: Pragma, additional_fields: Optional[Dict] = None) -> None:
         if additional_fields is None:
             additional_fields = {}
         type_specific_fields = {"directive": pragma.directive}
         element = _create_base_element(
             "pragma",
             pragma.version,
-            pragma.source_mapping,
+            pragma.source_mapping.to_json(),
             type_specific_fields,
             additional_fields,
         )
@@ -634,10 +670,10 @@ class Output:
     def add_other(
         self,
         name: str,
-        source_mapping,
+        source_mapping: Tuple[str, int, int],
         compilation_unit: "SlitherCompilationUnit",
         additional_fields: Optional[Dict] = None,
-    ):
+    ) -> None:
         # If this a tuple with (filename, start, end), convert it to a source mapping.
         if additional_fields is None:
             additional_fields = {}
@@ -667,7 +703,7 @@ class Output:
 
         # If this is a source mapping object, get the underlying source mapping dictionary
         if isinstance(source_mapping, SourceMapping):
-            source_mapping = source_mapping.source_mapping
+            source_mapping = source_mapping.source_mapping.to_json()
 
         # Create the underlying element and add it to our resulting json
         element = _create_base_element("other", name, source_mapping, {}, additional_fields)
