@@ -371,6 +371,11 @@ ALL_TEST_OBJECTS = [
         "uninitialized_storage_pointer.sol",
         "0.4.25",
     ),
+    Test(
+        all_detectors.UninitializedStorageVars,
+        "uninitialized_storage_pointer.sol",
+        "0.8.19",
+    ),
     Test(all_detectors.TxOrigin, "tx_origin.sol", "0.4.25"),
     Test(all_detectors.TxOrigin, "tx_origin.sol", "0.5.16"),
     Test(all_detectors.TxOrigin, "tx_origin.sol", "0.6.11"),
@@ -609,6 +614,26 @@ ALL_TEST_OBJECTS = [
         "naming_convention.sol",
         "0.7.6",
     ),
+    Test(
+        all_detectors.NamingConvention,
+        "no_warning_for_public_constants.sol",
+        "0.4.25",
+    ),
+    Test(
+        all_detectors.NamingConvention,
+        "no_warning_for_public_constants.sol",
+        "0.5.16",
+    ),
+    Test(
+        all_detectors.NamingConvention,
+        "no_warning_for_public_constants.sol",
+        "0.6.11",
+    ),
+    Test(
+        all_detectors.NamingConvention,
+        "no_warning_for_public_constants.sol",
+        "0.7.6",
+    ),
     Test(
         all_detectors.ControlledDelegateCall,
         "controlled_delegatecall.sol",
@@ -1603,6 +1628,16 @@ ALL_TEST_OBJECTS = [
         "var_read_using_this.sol",
         "0.8.15",
     ),
+    Test(
+        all_detectors.CyclomaticComplexity,
+        "HighCyclomaticComplexity.sol",
+        "0.8.16",
+    ),
+    Test(
+        all_detectors.CyclomaticComplexity,
+        "LowCyclomaticComplexity.sol",
+        "0.8.16",
+    ),
 ]
 
 
